use `qc`;

DROP TABLE IF EXISTS `qc_abnormal`;
CREATE TABLE `qc_abnormal` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `behospital_code` varchar(16) NOT NULL DEFAULT '' COMMENT '病人住院ID',
  `type` int(11) NOT NULL DEFAULT '1' COMMENT '异常类型(1:数据模块 2：质控类型 3：XML结构)',
  `description` varchar(255) NOT NULL DEFAULT '' COMMENT '异常描述',
  `status` int(11) NOT NULL DEFAULT '0' COMMENT '状态(0:未处理，1：已处理)',
  `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='异常数据监控信息';

DROP TABLE IF EXISTS `med_qcresult_cases`;
CREATE TABLE `med_qcresult_cases` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT,
  `hospital_id` bigint(20) DEFAULT '0' COMMENT '医院ID',
  `behospital_code` varchar(255) NOT NULL DEFAULT '' COMMENT '病人住院ID',
  `cases_id` bigint(20) DEFAULT '0' COMMENT '数据模块ID（0:其他模块）',
  `score_res` decimal(5,1) NOT NULL DEFAULT '0.0' COMMENT '最后得分',
  `level` varchar(20) NOT NULL DEFAULT '' COMMENT '等级',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  KEY `idx_behospital_code` (`behospital_code`) USING BTREE,
  KEY `idx_hospital_id` (`hospital_id`) USING BTREE,
  KEY `idx_hospital_id_behospital_code` (`hospital_id`,`behospital_code`) USING BTREE,
  KEY `idx_is_deleted` (`is_deleted`) USING BTREE,
  KEY `idx_mix` (`hospital_id`,`behospital_code`,`is_deleted`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='质控评分模块评分信息';

ALTER TABLE `qc`.`qc_model_hospital`
  ADD COLUMN `is_deleted` CHAR(3) DEFAULT 'N' NULL COMMENT '是否删除,N:未删除，Y:删除' AFTER `stand_model_name`,
  ADD COLUMN `gmt_create` DATETIME DEFAULT '1970-01-01 12:00:00' NULL COMMENT '记录创建时间' AFTER `is_deleted`,
  ADD COLUMN `gmt_modified` DATETIME DEFAULT '1970-01-01 12:00:00' NULL COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改' AFTER `gmt_create`,
  ADD COLUMN `creator` VARCHAR (60) DEFAULT '0' NULL COMMENT '创建人，0表示无创建人值' AFTER `gmt_modified`,
  ADD COLUMN `modifier` VARCHAR (60) DEFAULT '0' NULL COMMENT '修改人,如果为0则表示纪录未修改' AFTER `creator`,
  ADD COLUMN `remark` VARCHAR (255) NULL COMMENT '备注' AFTER `modifier` ;

INSERT INTO `qc`.`sys_task_cron` (`id`, `is_deleted`, `gmt_create`, `gmt_modified`, `creator`, `modifier`, `cron_code`, `cron`, `is_used`, `remark`) VALUES ('-1', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', 'TASK_CX', '0 0 22 * * ?', '1', '每天晚上自动评分出院日期之前3天的未评分数据');
UPDATE `qc`.`sys_task_cron` SET `id`='1', `is_deleted`='Y', `gmt_create`='1970-01-01 12:00:00', `gmt_modified`='1970-01-01 12:00:00', `creator`='0', `modifier`='0', `cron_code`='TASK001', `cron`='59 59 23 * * ?', `is_used`='1', `remark`='59 59 23 * * ?' WHERE (`id`='1');

-- ----------------------------
-- Table structure for sys_menu
-- ----------------------------
DROP TABLE IF EXISTS `sys_menu`;
CREATE TABLE `sys_menu` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT '菜单名称',
  `parent_id` bigint(20) NOT NULL DEFAULT '-1' COMMENT '-1：表示顶级,其他值表示上级菜单的id',
  `code` varchar(255) NOT NULL DEFAULT '' COMMENT '编码，与前端对应',
  `show_status` int(11) NOT NULL DEFAULT '0' COMMENT '是否在右侧菜单显示(0:不显示，1：显示)',
  `maintain_status` int(11) NOT NULL DEFAULT '0' COMMENT '是否可以维护(0:不可维护，1：可以维护)',
  `order_no` int(11) NOT NULL DEFAULT '0' COMMENT '排序，从小到大',
  `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=32 DEFAULT CHARSET=utf8 COMMENT='系统菜单';

-- ----------------------------
-- Records of sys_menu
-- ----------------------------
INSERT INTO `sys_menu` VALUES (1, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '控制台', -1, 'YH-KZT', 1, 1, -10, '用户-控制台');
INSERT INTO `sys_menu` VALUES (2, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '基础数据维护', -1, 'YH-JCSJWH', 1, 1, 2, '用户-基础数据维护');
INSERT INTO `sys_menu` VALUES (3, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '病案质控', -1, 'YH-BLZK', 1, 1, 3, '用户-病历质控');
INSERT INTO `sys_menu` VALUES (4, 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '统计分析', -1, 'YH-TJFX', 1, 1, 4, '用户-统计分析');
INSERT INTO `sys_menu` VALUES (5, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '模块数据维护', 2, 'YH-JCSJWH-MKSJWH', 1, 1, 1, '用户-基础数据维护-模块数据维护');
INSERT INTO `sys_menu` VALUES (6, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '条目数据维护', 2, 'YH-JCSJWH-TMSJWH', 1, 1, 2, '用户-基础数据维护-条目数据维护');
INSERT INTO `sys_menu` VALUES (7, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控评分', 3, 'YH-BLZK-ZKPF', 1, 1, 1, '用户-病历质控-质控评分');
INSERT INTO `sys_menu` VALUES (8, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '基础功能', -1, 'YH-QBYH-JCGN', 0, 1, 0, '用户-基础功能');
INSERT INTO `sys_menu` VALUES (9, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控评分(科室)', 3, 'YH-BLZK-ZKPFKS', 1, 1, 2, '用户-病历质控-质控评分(科室)');
INSERT INTO `sys_menu` VALUES (10, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控评分(个人)', 3, 'YH-BLZK-ZKPFGR', 1, 1, 3, '用户-病历质控-质控评分(个人)');
INSERT INTO `sys_menu` VALUES (12, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '权限管理', -1, 'YH-QXGL', 1, 0, 5, '用户-权限管理');
INSERT INTO `sys_menu` VALUES (13, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '用户管理', 12, 'YH-QXGL-YHGL', 1, 0, 1, '用户-权限管理-用户管理');
INSERT INTO `sys_menu` VALUES (14, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '角色管理', 12, 'YH-QXGL-JSGL', 1, 0, 2, '用户-权限管理-角色管理');
INSERT INTO `sys_menu` VALUES (15, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '控制台(科室)', -1, 'YH-KZTKS', 1, 1, -9, '用户-控制台（科室）');
INSERT INTO `sys_menu` VALUES (16, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '异常数据监控', -1, 'YH-YCSJJK', 1, 0, 10, '用户-异常数据监控');
INSERT INTO `sys_menu` VALUES (17, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '数据报表明细', -1, 'YH-ZKK', 1, 1, -8, '用户-质控科');
INSERT INTO `sys_menu` VALUES (18, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '数据报表明细(科室)', -1, 'YH-KSZR', 1, 1, -7, '用户-科室主任');
INSERT INTO `sys_menu` VALUES (19, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各模块缺陷占比', 17, 'YH-ZKK-GMKQXZB_XQ', 1, 1, 2, '用户-质控科-各模块缺陷占比_详情');
INSERT INTO `sys_menu` VALUES (20, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '条目缺陷占比', 17, 'YH-ZKK-TMQXZB_XQ', 1, 1, 3, '用户-质控科-条目缺陷占比_详情');
INSERT INTO `sys_menu` VALUES (21, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '科室平均住院天数', 17, 'YH-ZKK-KSPJZYTS_XQ', 1, 1, 4, '用户-质控科-科室平均住院天数_详情');
INSERT INTO `sys_menu` VALUES (22, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '科室平均住院花费', 17, 'YH-ZKK-KSPJZYHF_XQ', 1, 1, 5, '用户-质控科-科室平均住院花费_详情');
INSERT INTO `sys_menu` VALUES (23, 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室质控平均分', 17, 'YH-ZKK-GKSZKPJF_XQ', 1, 1, 6, '用户-质控科-各科室质控平均分_详情');
INSERT INTO `sys_menu` VALUES (24, 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '缺陷详情', 17, 'YH-ZKK-GKSQXZB', 1, 1, 7, '用户-质控科-各科室缺陷占比_详情');
INSERT INTO `sys_menu` VALUES (25, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室甲级病历占比', 17, 'YH-ZKK-GKSJJBLZB_XQ', 1, 1, 8, '用户-质控科-各科室甲级病历占比_详情');
INSERT INTO `sys_menu` VALUES (26, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各模块缺陷占比', 18, 'YH-KSZR-GMKQXZB_XQ', 1, 1, 2, '用户-科室主任-各模块缺陷占比_详情');
INSERT INTO `sys_menu` VALUES (27, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '条目缺陷占比', 18, 'YH-KSZR-TMQXZB_XQ', 1, 1, 3, '用户-科室主任-条目缺陷占比_详情');
INSERT INTO `sys_menu` VALUES (28, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '病案首页合格率占比', 17, 'YH-ZKK-BASYHGLZB_XQ', 1, 1, 1, '用户-质控科-病案首页合格率占比_详情');
INSERT INTO `sys_menu` VALUES (29, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '病案首页合格率占比', 18, 'YH-KSZR-BASYHGLZB_XQ', 1, 1, 1, '用户-科室主任-病案首页合格率占比_详情');
INSERT INTO `sys_menu` VALUES (30, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '科室缺陷占比', 18, 'YH-KSZR-KSQXZB_XQ', 1, 1, 4, '用户-科室主任-科室缺陷占比_详情');
INSERT INTO `sys_menu` VALUES (31, 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室缺陷占比', 17, 'YH-ZKK-GKSQXZB_XQ', 1, 1, 9, '用户-质控科-各科室缺陷占比_详情');

-- ----------------------------
-- Table structure for sys_menu_permission
-- ----------------------------
DROP TABLE IF EXISTS `sys_menu_permission`;
CREATE TABLE `sys_menu_permission` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `menu_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '菜单id',
  `permission_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '系统资源id',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=62 DEFAULT CHARSET=utf8 COMMENT='菜单和系统资源的映射表';

-- ----------------------------
-- Records of sys_menu_permission
-- ----------------------------
INSERT INTO `sys_menu_permission` VALUES ('1', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '8', '1', '基础功能-获取用户、机构、菜单信息');
INSERT INTO `sys_menu_permission` VALUES ('2', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '8', '2', '基础功能-修改密码');
INSERT INTO `sys_menu_permission` VALUES ('3', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '9', '控制台-病历相关统计');
INSERT INTO `sys_menu_permission` VALUES ('4', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '15', '控制台-缺陷相关统计');
INSERT INTO `sys_menu_permission` VALUES ('5', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '16', '控制台-医院运营相关统计');
INSERT INTO `sys_menu_permission` VALUES ('6', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '5', '3', '用户-基础数据维护-获取医院模块数据信息');
INSERT INTO `sys_menu_permission` VALUES ('7', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '5', '4', '用户-基础数据维护-批量更新模块数据');
INSERT INTO `sys_menu_permission` VALUES ('8', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '6', '6', '用户-条目数据维护-分页获取医院条目数据信息');
INSERT INTO `sys_menu_permission` VALUES ('9', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '6', '7', '用户-条目数据维护-修改医院条目数据信息');
INSERT INTO `sys_menu_permission` VALUES ('10', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '6', '8', '用户-条目数据维护-获取医院模块数据下拉列表');
INSERT INTO `sys_menu_permission` VALUES ('11', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '7', '30', '用户-质控评分-获取病历质控一览下医院科室下拉列表信息');
INSERT INTO `sys_menu_permission` VALUES ('12', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '7', '17', '用户-质控评分-评分');
INSERT INTO `sys_menu_permission` VALUES ('13', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '7', '5', '用户-质控评分-分页');
INSERT INTO `sys_menu_permission` VALUES ('14', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '7', '11', '用户-质控评分-新增质控条目');
INSERT INTO `sys_menu_permission` VALUES ('15', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '7', '12', '用户-质控评分-删除质控条目');
INSERT INTO `sys_menu_permission` VALUES ('16', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '7', '13', '用户-质控评分-修改质控条目');
INSERT INTO `sys_menu_permission` VALUES ('17', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '7', '14', '用户-质控评分-获取详情');
INSERT INTO `sys_menu_permission` VALUES ('18', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '9', '31', '用户-质控评分(科室)-获取病历质控一览下用户科室下拉列表信息');
INSERT INTO `sys_menu_permission` VALUES ('19', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '9', '34', '用户-质控评分(科室)-评分');
INSERT INTO `sys_menu_permission` VALUES ('20', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '9', '32', '用户-质控评分(科室)-分页');
INSERT INTO `sys_menu_permission` VALUES ('21', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '9', '35', '用户-质控评分(科室)-新增质控条目');
INSERT INTO `sys_menu_permission` VALUES ('22', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '9', '36', '用户-质控评分(科室)-删除质控条目');
INSERT INTO `sys_menu_permission` VALUES ('23', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '9', '37', '用户-质控评分(科室)-修改质控条目');
INSERT INTO `sys_menu_permission` VALUES ('24', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '9', '38', '用户-质控评分(科室)-获取详情');
INSERT INTO `sys_menu_permission` VALUES ('25', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '10', '39', '用户-质控评分(个人)-获取病历质控一览下用户科室下拉列表信息');
INSERT INTO `sys_menu_permission` VALUES ('26', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '10', '40', '用户-质控评分(个人)-评分');
INSERT INTO `sys_menu_permission` VALUES ('27', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '10', '33', '用户-质控评分(个人)-分页');
INSERT INTO `sys_menu_permission` VALUES ('28', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '10', '41', '用户-质控评分(个人)-新增质控条目');
INSERT INTO `sys_menu_permission` VALUES ('29', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '10', '42', '用户-质控评分(个人)-删除质控条目');
INSERT INTO `sys_menu_permission` VALUES ('30', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '10', '43', '用户-质控评分(个人)-修改质控条目');
INSERT INTO `sys_menu_permission` VALUES ('31', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '10', '44', '用户-质控评分(个人)-获取详情');
INSERT INTO `sys_menu_permission` VALUES ('32', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '45', '控制台-平均住院天数');
INSERT INTO `sys_menu_permission` VALUES ('33', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '46', '控制台-平均住院费用');
INSERT INTO `sys_menu_permission` VALUES ('34', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '47', '控制台-质控平均分按科室统计');
INSERT INTO `sys_menu_permission` VALUES ('35', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '48', '控制台-各科室甲级病历占比');
INSERT INTO `sys_menu_permission` VALUES ('36', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '49', '控制台-出院人数统计');
INSERT INTO `sys_menu_permission` VALUES ('37', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '50', '控制台-质控病历统计');
INSERT INTO `sys_menu_permission` VALUES ('38', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '51', '控制台-各模块缺陷占比排行');
INSERT INTO `sys_menu_permission` VALUES ('39', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '52', '控制台-条目缺陷占比');
INSERT INTO `sys_menu_permission` VALUES ('40', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '53', '控制台-各科室缺陷占比');
INSERT INTO `sys_menu_permission` VALUES ('41', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '15', '54', '控制台（科室）-出院人数统计（科室）');
INSERT INTO `sys_menu_permission` VALUES ('42', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '15', '55', '控制台（科室）-质控病历数统计（科室）');
INSERT INTO `sys_menu_permission` VALUES ('43', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '15', '56', '控制台（科室）-各模块缺陷占比排行（科室）');
INSERT INTO `sys_menu_permission` VALUES ('44', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '15', '57', '控制台（科室）-条目缺陷占比（科室）');
INSERT INTO `sys_menu_permission` VALUES ('45', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '15', '58', '控制台（科室）-查询用户关联科室');
INSERT INTO `sys_menu_permission` VALUES ('46', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '19', '59', '控制台-各模块缺陷占比_详情');
INSERT INTO `sys_menu_permission` VALUES ('47', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '20', '60', '控制台-条目缺陷占比_详情');
INSERT INTO `sys_menu_permission` VALUES ('48', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '21', '64', '控制台-科室平均住院天数_详情');
INSERT INTO `sys_menu_permission` VALUES ('49', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '22', '65', '控制台-科室平均住院花费_详情');
INSERT INTO `sys_menu_permission` VALUES ('50', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '66', '控制台-各科室质控平均分_详情');
INSERT INTO `sys_menu_permission` VALUES ('51', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '31', '67', '控制台-各科室缺陷占比-缺陷详情');
INSERT INTO `sys_menu_permission` VALUES ('52', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '25', '68', '控制台-各科室甲级病历占比_详情');
INSERT INTO `sys_menu_permission` VALUES ('53', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '26', '69', '控制台（科室）-各模块缺陷占比_详情');
INSERT INTO `sys_menu_permission` VALUES ('54', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '27', '70', '控制台（科室）-条目缺陷占比_详情');
INSERT INTO `sys_menu_permission` VALUES ('55', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '31', '71', '控制台-各科室缺陷占比（组合）');
INSERT INTO `sys_menu_permission` VALUES ('56', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '28', '72', '控制台-病案首页合格率占比');
INSERT INTO `sys_menu_permission` VALUES ('57', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '30', '73', '控制台（科室）-各科室缺陷占比（科室）');
INSERT INTO `sys_menu_permission` VALUES ('58', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '29', '74', '控制台（科室）-病案首页合格率占比（科室）');
INSERT INTO `sys_menu_permission` VALUES ('59', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '75', '控制台-病案首页合格率占比（首页）');
INSERT INTO `sys_menu_permission` VALUES ('60', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '15', '76', '控制台（科室）-病案首页合格率占比（首页）');
INSERT INTO `sys_menu_permission` VALUES ('61', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '30', '77', '控制台（科室）-科室缺陷占比-缺陷明细');

-- ----------------------------
-- Table structure for sys_permission
-- ----------------------------
DROP TABLE IF EXISTS `sys_permission`;
CREATE TABLE `sys_permission` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '资源ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT '资源名称',
  `code` varchar(20) NOT NULL DEFAULT '' COMMENT '资源编码',
  `permissionUrl` varchar(255) NOT NULL DEFAULT '' COMMENT '资源Url',
  `method` varchar(255) NOT NULL DEFAULT 'ALL' COMMENT '资源允许的请求方式',
  `descritpion` varchar(255) NOT NULL DEFAULT '' COMMENT '资源描述',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=78 DEFAULT CHARSET=utf8 COMMENT='系统资源表';

-- ----------------------------
-- Records of sys_permission
-- ----------------------------
INSERT INTO `sys_permission` VALUES ('1', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取用户、机构、菜单信息', 'FUNC000001', '/sys/user/getUserOrgMenu', 'ALL', '基础功能-获取用户、机构、菜单信息', null);
INSERT INTO `sys_permission` VALUES ('2', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '修改密码', 'FUNC000002', '/sys/user/midifyPassword', 'ALL', '基础功能-修改密码', null);
INSERT INTO `sys_permission` VALUES ('3', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取医院模块数据信息', 'FUNC000003', '/qc/cases/getQcCases', 'ALL', '用户-基础数据维护-获取医院模块数据信息', '无需加密');
INSERT INTO `sys_permission` VALUES ('4', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '修改医院模块数据', 'FUNC000004', '/qc/cases/saveQcCases', 'ALL', '用户-基础数据维护-修改医院模块数据', null);
INSERT INTO `sys_permission` VALUES ('5', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '分页查询', 'FUNC000005', '/qc/behospitalInfo/page', 'ALL', '用户-质控评分-分页', '无需加密');
INSERT INTO `sys_permission` VALUES ('6', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '分页获取医院条目数据信息', 'FUNC000006', '/qc/casesEntryHospital/getQcCasesEntryAll', 'ALL', '用户-条目数据维护-分页获取医院条目数据信息', '无需加密');
INSERT INTO `sys_permission` VALUES ('7', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '修改医院条目数据信息', 'FUNC000007', '/qc/casesEntryHospital/updataQcCasesEntry', 'ALL', '用户-条目数据维护-修改医院条目数据信息', null);
INSERT INTO `sys_permission` VALUES ('8', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取医院模块下拉数据列表', 'FUNC000008', '/qc/casesEntryHospital/getQcCasesAll', 'ALL', '获取医院模块数据列表', '无需加密');
INSERT INTO `sys_permission` VALUES ('9', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '病历相关统计', 'FUNC000009', '/console/mrStatistics', 'ALL', '控制台-病历相关统计', null);
INSERT INTO `sys_permission` VALUES ('10', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '模糊查询医院模块条目列表', 'FUNC000010', '/qc/casesEntryHospital/findQcCasesEntry', 'ALL', '用户-条目数据维护-模糊查询医院模块条目列表', null);
INSERT INTO `sys_permission` VALUES ('11', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '新增质控条目', 'FUNC000011', '/qc/behospitalInfo/addCase', 'ALL', '用户-质控评分-新增质控条目', null);
INSERT INTO `sys_permission` VALUES ('12', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '删除质控条目', 'FUNC000012', '/qc/behospitalInfo/delCase', 'ALL', '用户-质控评分-删除质控条目', null);
INSERT INTO `sys_permission` VALUES ('13', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '修改质控条目', 'FUNC000013', '/qc/behospitalInfo/updCase', 'ALL', '用户-质控评分-修改质控条目', null);
INSERT INTO `sys_permission` VALUES ('14', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取质控评分详情', 'FUNC000014', '/qc/behospitalInfo/getByBehospitalCode', 'ALL', '用户-质控评分-获取详情', '无需加密');
INSERT INTO `sys_permission` VALUES ('15', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '缺陷相关统计', 'FUNC000015', '/console/resultStatistics', 'ALL', '控制台-缺陷相关统计', null);
INSERT INTO `sys_permission` VALUES ('16', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '平均值相关统计', 'FUNC000016', '/console/averageStatistics', 'ALL', '控制台-平均值相关统计', null);
INSERT INTO `sys_permission` VALUES ('17', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控评分', 'FUNC000017', '/qc/behospitalInfo/analyze', 'ALL', '用户-质控评分-评分', null);
INSERT INTO `sys_permission` VALUES ('18', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取角色列表信息', 'FUNC000018', '/sys/role/list', 'ALL', '用户-权限管理-角色管理-获取角色列表信息', null);
INSERT INTO `sys_permission` VALUES ('19', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取角色菜权限单等数据', 'FUNC000019', '/sys/role/getRoleMenu', 'ALL', '用户-权限管理-角色管理-获取角色菜权限单等数据', null);
INSERT INTO `sys_permission` VALUES ('20', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '修改角色菜单权限数据', 'FUNC000020', '/sys/role/saveRoleMenu', 'ALL', '用户-权限管理-角色管理-修改角色菜单权限数据', null);
INSERT INTO `sys_permission` VALUES ('21', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取医院科室下拉列表信息', 'FUNC000021', '/bas/dept/listForUser', 'ALL', '用户-权限管理-用户管理-获取用户管理下医院科室下拉列表信息', null);
INSERT INTO `sys_permission` VALUES ('22', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取角色下拉列表信息', 'FUNC000022', '/sys/role/listForUser', 'ALL', '用户-权限管理-用户管理-获取角色下拉列表信息', null);
INSERT INTO `sys_permission` VALUES ('23', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '用户列表翻页信息查询', 'FUNC000023', '/sys/user/userPage', 'ALL', '用户-权限管理-用户管理-用户列表翻页信息查询', null);
INSERT INTO `sys_permission` VALUES ('24', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取用户科室', 'FUNC000024', '/sys/user/getUserDepts', 'ALL', '用户-权限管理-用户管理-获取用户科室', null);
INSERT INTO `sys_permission` VALUES ('25', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取用户角色', 'FUNC000025', '/sys/user/getUserRoles', 'ALL', '用户-权限管理-用户管理-获取用户角色', null);
INSERT INTO `sys_permission` VALUES ('26', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '用户启用', 'FUNC000026', '/sys/user/enable', 'ALL', '用户-权限管理-用户管理-用户启用', null);
INSERT INTO `sys_permission` VALUES ('27', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '用户停用', 'FUNC000027', '/sys/user/disable', 'ALL', '用户-权限管理-用户管理-用户停用', null);
INSERT INTO `sys_permission` VALUES ('28', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '编辑用户科室', 'FUNC000028', '/sys/user/editUserDepts', 'ALL', '用户-权限管理-用户管理-编辑用户科室', null);
INSERT INTO `sys_permission` VALUES ('29', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '编辑用户角色', 'FUNC000029', '/sys/user/editUserRoles', 'ALL', '用户-权限管理-用户管理-编辑用户角色', null);
INSERT INTO `sys_permission` VALUES ('30', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取医院科室下拉列表信息', 'FUNC000030', '/bas/dept/getList', 'ALL', '用户-质控评分-获取病历质控一览下医院科室下拉列表信息', '无需加密');
INSERT INTO `sys_permission` VALUES ('31', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取用户科室下拉列表信息', 'FUNC000031', '/bas/dept/getListUser', 'ALL', '用户-质控评分(科室)-获取病历质控一览下用户科室下拉列表信息', '无需加密');
INSERT INTO `sys_permission` VALUES ('32', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '分页查询', 'FUNC000032', '/qc/behospitalInfo/page_dept', 'ALL', '用户-质控评分(科室)-分页', '无需加密');
INSERT INTO `sys_permission` VALUES ('33', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '分页查询', 'FUNC000033', '/qc/behospitalInfo/page_person', 'ALL', '用户-质控评分(个人)-分页', '无需加密');
INSERT INTO `sys_permission` VALUES ('34', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控评分', 'FUNC000017', '/qc/behospitalInfo/analyze', 'ALL', '用户-质控评分(科室)-评分', null);
INSERT INTO `sys_permission` VALUES ('35', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '新增质控条目', 'FUNC000011', '/qc/behospitalInfo/addCase', 'ALL', '用户-质控评分(科室)-新增质控条目', null);
INSERT INTO `sys_permission` VALUES ('36', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '删除质控条目', 'FUNC000012', '/qc/behospitalInfo/delCase', 'ALL', '用户-质控评分(科室)-删除质控条目', null);
INSERT INTO `sys_permission` VALUES ('37', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '修改质控条目', 'FUNC000013', '/qc/behospitalInfo/updCase', 'ALL', '用户-质控评分(科室)-修改质控条目', null);
INSERT INTO `sys_permission` VALUES ('38', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取质控评分详情', 'FUNC000014', '/qc/behospitalInfo/getByBehospitalCode', 'ALL', '用户-质控评分(科室)-获取详情', '无需加密');
INSERT INTO `sys_permission` VALUES ('39', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取用户科室下拉列表信息', 'FUNC000031', '/bas/dept/getListUser', 'ALL', '用户-质控评分(个人)-获取病历质控一览下用户科室下拉列表信息', '无需加密');
INSERT INTO `sys_permission` VALUES ('40', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控评分', 'FUNC000017', '/qc/behospitalInfo/analyze', 'ALL', '用户-质控评分(个人)-评分', null);
INSERT INTO `sys_permission` VALUES ('41', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '新增质控条目', 'FUNC000011', '/qc/behospitalInfo/addCase', 'ALL', '用户-质控评分(个人)-新增质控条目', null);
INSERT INTO `sys_permission` VALUES ('42', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '删除质控条目', 'FUNC000012', '/qc/behospitalInfo/delCase', 'ALL', '用户-质控评分(个人)-删除质控条目', null);
INSERT INTO `sys_permission` VALUES ('43', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '修改质控条目', 'FUNC000013', '/qc/behospitalInfo/updCase', 'ALL', '用户-质控评分(个人)-修改质控条目', null);
INSERT INTO `sys_permission` VALUES ('44', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '获取质控评分详情', 'FUNC000014', '/qc/behospitalInfo/getByBehospitalCode', 'ALL', '用户-质控评分(个人)-获取详情', '无需加密');
INSERT INTO `sys_permission` VALUES ('45', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '平均住院天数', 'FUNC000045', '/console/getAverageDayNum', 'ALL', '控制台-平均住院天数', null);
INSERT INTO `sys_permission` VALUES ('46', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '平均住院费用', 'FUNC000046', '/console/getAverageFee', 'ALL', '控制台-平均住院费用', null);
INSERT INTO `sys_permission` VALUES ('47', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控平均分按科室统计', 'FUNC000047', '/console/getAverageScore', 'ALL', '控制台-质控平均分按科室统计', null);
INSERT INTO `sys_permission` VALUES ('48', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室甲级病历占比', 'FUNC000048', '/console/getLevelResultDept', 'ALL', '控制台-各科室甲级病历占比', null);
INSERT INTO `sys_permission` VALUES ('49', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '出院人数统计', 'FUNC000049', '/console/leaveHosCount', 'ALL', '控制台-出院人数统计', null);
INSERT INTO `sys_permission` VALUES ('50', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控病历统计', 'FUNC000050', '/console/mrCount', 'ALL', '控制台-质控病历统计', null);
INSERT INTO `sys_permission` VALUES ('51', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各模块缺陷占比排行', 'FUNC000051', '/console/entryCountGroupByCase', 'ALL', '控制台-各模块缺陷占比排行', null);
INSERT INTO `sys_permission` VALUES ('52', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '条目缺陷占比', 'FUNC000052', '/console/entryCountGroupByEntry', 'ALL', '控制台-条目缺陷占比', null);
INSERT INTO `sys_permission` VALUES ('53', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室缺陷占比', 'FUNC000053', '/console/entryByDept', 'ALL', '控制台-各科室缺陷占比', null);
INSERT INTO `sys_permission` VALUES ('54', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '出院人数统计（科室）', 'FUNC000054', '/consoleByDept/leaveHosCountByDept', 'ALL', '控制台（科室）-出院人数统计（科室）', null);
INSERT INTO `sys_permission` VALUES ('55', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '质控病历数统计（科室）', 'FUNC000055', '/consoleByDept/mrCountByDept', 'ALL', '控制台（科室）-质控病历数统计（科室）', null);
INSERT INTO `sys_permission` VALUES ('56', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各模块缺陷占比排行（科室）', 'FUNC000056', '/consoleByDept/entryCountGroupByCaseAndDept', 'ALL', '控制台（科室）-各模块缺陷占比排行（科室）', null);
INSERT INTO `sys_permission` VALUES ('57', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '条目缺陷占比（科室）', 'FUNC000057', '/consoleByDept/entryCountGroupByEntryAndDept', 'ALL', '控制台（科室）-条目缺陷占比（科室）', null);
INSERT INTO `sys_permission` VALUES ('58', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '查询用户关联科室', 'FUNC000058', '/consoleByDept/getDept', 'ALL', '控制台（科室）-查询用户关联科室', null);
INSERT INTO `sys_permission` VALUES ('59', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各模块缺陷占比_详情', 'FUNC000059', '/console/entryCountGroupByCasePage', 'ALL', '控制台-各模块缺陷占比_详情', null);
INSERT INTO `sys_permission` VALUES ('60', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '条目缺陷占比_详情', 'FUNC000060', '/console/entryCountGroupByEntryPage', 'ALL', '控制台-条目缺陷占比_详情', null);
INSERT INTO `sys_permission` VALUES ('61', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '查询异常数据监控信息', 'FUNC000061', '/qc/abnormal/getQcAnnormal', 'ALL', '异常数据监控-查询异常数据监控信息', null);
INSERT INTO `sys_permission` VALUES ('62', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '更新异常数据监控信息', 'FUNC000062', '/qc/abnormal/saveQcAnnormal', 'ALL', '异常数据监控-异常数据监控-查询异常数据监控信息', null);
INSERT INTO `sys_permission` VALUES ('63', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '删除异常数据监控信息', 'FUNC000063', '/qc/abnormal/delQcAnnormal', 'ALL', '异常数据监控-异常数据监控-删除异常数据监控信息', null);
INSERT INTO `sys_permission` VALUES ('64', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '科室平均住院天数_详情', 'FUNC000064', '/console/getAverageDayNumPage', 'ALL', '控制台-科室平均住院天数_详情', null);
INSERT INTO `sys_permission` VALUES ('65', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '科室平均住院花费_详情', 'FUNC000065', '/console/getAverageFeePage', 'ALL', '控制台-科室平均住院花费_详情', null);
INSERT INTO `sys_permission` VALUES ('66', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室质控平均分_详情', 'FUNC000066', '/console/getAverageScoreByDeptPage', 'ALL', '控制台-各科室质控平均分_详情', null);
INSERT INTO `sys_permission` VALUES ('67', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室缺陷占比-缺陷详情', 'FUNC000067', '/console/resultStatisticsByDeptPage', 'ALL', '控制台-各科室缺陷占比-缺陷详情', null);
INSERT INTO `sys_permission` VALUES ('68', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室甲级病历占比_详情', 'FUNC000068', '/console/levelPercentGroupByDeptPage', 'ALL', '控制台-各科室甲级病历占比_详情', null);
INSERT INTO `sys_permission` VALUES ('69', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各模块缺陷占比_详情', 'FUNC000069', '/consoleByDept/entryCountGroupByCaseAndDeptPage', 'ALL', '控制台（科室）-各模块缺陷占比_详情', null);
INSERT INTO `sys_permission` VALUES ('70', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '条目缺陷占比_详情', 'FUNC000070', '/consoleByDept/entryCountGroupByEntryAndDeptPage', 'ALL', '控制台（科室）-条目缺陷占比_详情', null);
INSERT INTO `sys_permission` VALUES ('71', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室缺陷占比（组合）', 'FUNC000071', '/console/levelStatistics', 'ALL', '控制台-各科室缺陷占比（组合）', null);
INSERT INTO `sys_permission` VALUES ('72', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '病案首页合格率占比', 'FUNC000072', '/console/homePageLevelStatistics', 'ALL', '控制台-病案首页合格率占比', null);
INSERT INTO `sys_permission` VALUES ('73', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '各科室缺陷占比', 'FUNC000073', '/consoleByDept/levelStatisticsByDept', 'ALL', '控制台（科室）-各科室缺陷占比（科室）', null);
INSERT INTO `sys_permission` VALUES ('74', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '病案首页合格率占比', 'FUNC000074', '/consoleByDept/homePageLevelStatisticsByDept', 'ALL', '控制台（科室）-病案首页合格率占比（科室）', null);
INSERT INTO `sys_permission` VALUES ('75', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '病案首页合格率占比（首页）', 'FUNC000075', '/console/homePageLevelLimit', 'ALL', '控制台-病案首页合格率占比（首页）', null);
INSERT INTO `sys_permission` VALUES ('76', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '病案首页合格率占比（首页）', 'FUNC000076', '/consoleByDept/homePageLevelByDeptLimit', 'ALL', '控制台（科室）-病案首页合格率占比（首页）', null);
INSERT INTO `sys_permission` VALUES ('77', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '科室缺陷占比-缺陷明细', 'FUNC000077', '/consoleByDept/resultStatisticsByDeptAndDoctorPage', 'ALL', '控制台（科室）-科室缺陷占比-缺陷明细', null);

-- ----------------------------
-- Table structure for sys_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_role`;
CREATE TABLE `sys_role` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '角色ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT '角色名称',
  `roleLevel` int(11) NOT NULL DEFAULT '0' COMMENT '角色等级',
  `descritpion` varchar(255) NOT NULL DEFAULT '' COMMENT '角色描述',
  `menuItems` varchar(255) NOT NULL DEFAULT '' COMMENT '菜单ID：对应角色ID(暂无用处)',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COMMENT='系统角色表';

-- ----------------------------
-- Records of sys_role
-- ----------------------------
INSERT INTO `sys_role` VALUES ('-1', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '超级管理员', '0', '', '', '');
INSERT INTO `sys_role` VALUES ('1', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '医院人员(全局)', '0', '', '', '');
INSERT INTO `sys_role` VALUES ('2', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '医院人员(科室)', '0', '', '', null);
INSERT INTO `sys_role` VALUES ('3', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '医院人员(个人)', '0', '', '', null);

-- ----------------------------
-- Table structure for sys_role_menu
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_menu`;
CREATE TABLE `sys_role_menu` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `role_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '角色id',
  `menu_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '菜单id',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=591 DEFAULT CHARSET=utf8 COMMENT='角色和菜单的映射表';

-- ----------------------------
-- Records of sys_role_menu
-- ----------------------------
INSERT INTO `sys_role_menu` VALUES ('10', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '1', null);
INSERT INTO `sys_role_menu` VALUES ('11', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '2', null);
INSERT INTO `sys_role_menu` VALUES ('12', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '3', null);
INSERT INTO `sys_role_menu` VALUES ('13', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '4', null);
INSERT INTO `sys_role_menu` VALUES ('14', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '5', null);
INSERT INTO `sys_role_menu` VALUES ('15', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '6', null);
INSERT INTO `sys_role_menu` VALUES ('16', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '7', null);
INSERT INTO `sys_role_menu` VALUES ('17', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '8', null);
INSERT INTO `sys_role_menu` VALUES ('18', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '9', null);
INSERT INTO `sys_role_menu` VALUES ('19', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '10', null);
INSERT INTO `sys_role_menu` VALUES ('20', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '12', null);
INSERT INTO `sys_role_menu` VALUES ('21', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '13', null);
INSERT INTO `sys_role_menu` VALUES ('22', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '14', null);
INSERT INTO `sys_role_menu` VALUES ('499', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '15', null);
INSERT INTO `sys_role_menu` VALUES ('543', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '1', null);
INSERT INTO `sys_role_menu` VALUES ('544', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '8', null);
INSERT INTO `sys_role_menu` VALUES ('545', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '2', null);
INSERT INTO `sys_role_menu` VALUES ('546', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '5', null);
INSERT INTO `sys_role_menu` VALUES ('547', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '6', null);
INSERT INTO `sys_role_menu` VALUES ('548', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '3', null);
INSERT INTO `sys_role_menu` VALUES ('549', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '7', null);
INSERT INTO `sys_role_menu` VALUES ('550', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '16', '用户-异常数据监控');
INSERT INTO `sys_role_menu` VALUES ('551', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '17', '用户-质控科');
INSERT INTO `sys_role_menu` VALUES ('552', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '18', '用户-科室主任');
INSERT INTO `sys_role_menu` VALUES ('553', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '19', '用户-质控科-各模块缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('554', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '20', '用户-质控科-条目缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('555', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '21', '用户-质控科-科室平均住院天数_详情');
INSERT INTO `sys_role_menu` VALUES ('556', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '22', '用户-质控科-科室平均住院花费_详情');
INSERT INTO `sys_role_menu` VALUES ('557', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '23', '用户-质控科-各科室质控平均分_详情');
INSERT INTO `sys_role_menu` VALUES ('558', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '24', '用户-质控科-各科室缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('559', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '25', '用户-质控科-各科室甲级病历占比_详情');
INSERT INTO `sys_role_menu` VALUES ('560', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '26', '用户-科室主任-各模块缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('561', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '27', '用户-科室主任-条目缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('562', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '15', null);
INSERT INTO `sys_role_menu` VALUES ('563', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '8', null);
INSERT INTO `sys_role_menu` VALUES ('564', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '2', null);
INSERT INTO `sys_role_menu` VALUES ('565', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '5', null);
INSERT INTO `sys_role_menu` VALUES ('566', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '6', null);
INSERT INTO `sys_role_menu` VALUES ('567', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '3', null);
INSERT INTO `sys_role_menu` VALUES ('568', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '10', null);
INSERT INTO `sys_role_menu` VALUES ('569', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '15', null);
INSERT INTO `sys_role_menu` VALUES ('570', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '8', null);
INSERT INTO `sys_role_menu` VALUES ('571', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '2', null);
INSERT INTO `sys_role_menu` VALUES ('572', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '5', null);
INSERT INTO `sys_role_menu` VALUES ('573', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '6', null);
INSERT INTO `sys_role_menu` VALUES ('574', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '3', null);
INSERT INTO `sys_role_menu` VALUES ('575', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '9', null);
INSERT INTO `sys_role_menu` VALUES ('576', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '17', '用户-质控科');
INSERT INTO `sys_role_menu` VALUES ('577', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '2', '18', '用户-科室主任');
INSERT INTO `sys_role_menu` VALUES ('578', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '19', '用户-质控科-各模块缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('579', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '20', '用户-质控科-条目缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('580', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '21', '用户-质控科-科室平均住院天数_详情');
INSERT INTO `sys_role_menu` VALUES ('581', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '22', '用户-质控科-科室平均住院花费_详情');
INSERT INTO `sys_role_menu` VALUES ('582', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '23', '用户-质控科-各科室质控平均分_详情');
INSERT INTO `sys_role_menu` VALUES ('583', 'Y', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '24', '用户-质控科-各科室缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('584', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '25', '用户-质控科-各科室甲级病历占比_详情');
INSERT INTO `sys_role_menu` VALUES ('585', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '2', '26', '用户-科室主任-各模块缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('586', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '2', '27', '用户-科室主任-条目缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('587', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '28', '用户-质控科-病案首页合格率占比_详情');
INSERT INTO `sys_role_menu` VALUES ('588', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '29', '用户-科室主任-病案首页合格率占比_详情');
INSERT INTO `sys_role_menu` VALUES ('589', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '30', '用户-科室主任-科室缺陷占比_详情');
INSERT INTO `sys_role_menu` VALUES ('590', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '31', '用户-质控科-各科室缺陷占比_详情');

-- ----------------------------
-- Table structure for sys_role_permission
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_permission`;
CREATE TABLE `sys_role_permission` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `role_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '角色id',
  `permission_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '资源id',
  `remark` varchar(255) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1235 DEFAULT CHARSET=utf8 COMMENT='角色和资源的映射表';

-- ----------------------------
-- Records of sys_role_permission
-- ----------------------------
INSERT INTO `sys_role_permission` VALUES ('5', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '1', '基础功能-获取用户、机构、菜单信息');
INSERT INTO `sys_role_permission` VALUES ('6', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '2', '基础功能-修改密码');
INSERT INTO `sys_role_permission` VALUES ('20', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '3', '用户-基础数据维护-获取医院模块数据信息');
INSERT INTO `sys_role_permission` VALUES ('21', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '4', '用户-基础数据维护-批量更新模块数据');
INSERT INTO `sys_role_permission` VALUES ('22', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '5', '用户-质控评分-分页');
INSERT INTO `sys_role_permission` VALUES ('23', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '6', '用户-条目数据维护-分页获取医院条目数据信息');
INSERT INTO `sys_role_permission` VALUES ('24', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '7', '用户-条目数据维护-修改医院条目数据信息');
INSERT INTO `sys_role_permission` VALUES ('25', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '8', '用户-条目数据维护-获取医院模块数据列表');
INSERT INTO `sys_role_permission` VALUES ('26', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '9', '控制台-病历相关统计');
INSERT INTO `sys_role_permission` VALUES ('27', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '10', '用户-条目数据维护-模糊查询医院模块条目列表');
INSERT INTO `sys_role_permission` VALUES ('28', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '11', '用户-质控评分-新增质控条目');
INSERT INTO `sys_role_permission` VALUES ('29', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '12', '用户-质控评分-删除质控条目');
INSERT INTO `sys_role_permission` VALUES ('30', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '13', '用户-质控评分-修改质控条目');
INSERT INTO `sys_role_permission` VALUES ('31', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '14', '用户-质控评分-获取详情');
INSERT INTO `sys_role_permission` VALUES ('32', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '15', '控制台-缺陷相关统计');
INSERT INTO `sys_role_permission` VALUES ('33', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '16', '控制台-医院运营相关统计');
INSERT INTO `sys_role_permission` VALUES ('34', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '17', '用户-质控评分-评分');
INSERT INTO `sys_role_permission` VALUES ('35', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '18', '用户-权限管理-角色管理-获取角色列表信息');
INSERT INTO `sys_role_permission` VALUES ('36', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '19', '用户-权限管理-角色管理-获取角色菜权限单等数据');
INSERT INTO `sys_role_permission` VALUES ('37', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '20', '用户-权限管理-角色管理-修改角色菜单权限数据');
INSERT INTO `sys_role_permission` VALUES ('38', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '21', '用户-权限管理-用户管理-获取医院科室下拉列表信息');
INSERT INTO `sys_role_permission` VALUES ('39', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '22', '用户-权限管理-用户管理-获取角色下拉列表信息');
INSERT INTO `sys_role_permission` VALUES ('40', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '23', '用户-权限管理-用户管理-用户列表翻页信息查询');
INSERT INTO `sys_role_permission` VALUES ('41', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '24', '用户-权限管理-用户管理-获取用户科室');
INSERT INTO `sys_role_permission` VALUES ('42', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '25', '用户-权限管理-用户管理-获取用户角色');
INSERT INTO `sys_role_permission` VALUES ('43', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '26', '用户-权限管理-用户管理-用户启用');
INSERT INTO `sys_role_permission` VALUES ('44', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '27', '用户-权限管理-用户管理-用户停用');
INSERT INTO `sys_role_permission` VALUES ('45', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '28', '用户-权限管理-用户管理-编辑用户科室');
INSERT INTO `sys_role_permission` VALUES ('46', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '29', '用户-权限管理-用户管理-编辑用户角色');
INSERT INTO `sys_role_permission` VALUES ('47', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '30', '用户-质控评分-获取病历质控一览下医院科室下拉列表信息');
INSERT INTO `sys_role_permission` VALUES ('48', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '31', '用户-质控评分-获取病历质控一览下用户科室下拉列表信息');
INSERT INTO `sys_role_permission` VALUES ('50', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '32', '用户-质控评分(科室)-分页');
INSERT INTO `sys_role_permission` VALUES ('51', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '33', '用户-质控评分(个人)-分页');
INSERT INTO `sys_role_permission` VALUES ('52', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '34', '用户-质控评分(科室)-评分');
INSERT INTO `sys_role_permission` VALUES ('53', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '35', '用户-质控评分(科室)-新增质控条目');
INSERT INTO `sys_role_permission` VALUES ('54', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '36', '用户-质控评分(科室)-删除质控条目');
INSERT INTO `sys_role_permission` VALUES ('55', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '37', '用户-质控评分(科室)-修改质控条目');
INSERT INTO `sys_role_permission` VALUES ('56', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '38', '用户-质控评分(科室)-获取详情');
INSERT INTO `sys_role_permission` VALUES ('57', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '39', '用户-质控评分(个人)-获取病历质控一览下用户科室下拉列表信息');
INSERT INTO `sys_role_permission` VALUES ('58', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '40', '用户-质控评分(科室)-评分');
INSERT INTO `sys_role_permission` VALUES ('59', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '41', '用户-质控评分(科室)-新增质控条目');
INSERT INTO `sys_role_permission` VALUES ('60', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '42', '用户-质控评分(科室)-删除质控条目');
INSERT INTO `sys_role_permission` VALUES ('61', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '43', '用户-质控评分(科室)-修改质控条目');
INSERT INTO `sys_role_permission` VALUES ('62', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '44', '用户-质控评分(科室)-获取详情');
INSERT INTO `sys_role_permission` VALUES ('502', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '45', '控制台-平均住院天数');
INSERT INTO `sys_role_permission` VALUES ('503', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '46', '控制台-平均住院费用');
INSERT INTO `sys_role_permission` VALUES ('504', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '47', '控制台-质控平均分按科室统计');
INSERT INTO `sys_role_permission` VALUES ('505', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '48', '控制台-各科室甲级病历占比');
INSERT INTO `sys_role_permission` VALUES ('506', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '49', '控制台-出院人数统计');
INSERT INTO `sys_role_permission` VALUES ('507', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '50', '控制台-质控病历统计');
INSERT INTO `sys_role_permission` VALUES ('508', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '51', '控制台-各模块缺陷占比排行');
INSERT INTO `sys_role_permission` VALUES ('509', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '52', '控制台-条目缺陷占比');
INSERT INTO `sys_role_permission` VALUES ('510', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '53', '控制台-各科室缺陷占比');
INSERT INTO `sys_role_permission` VALUES ('511', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '54', '控制台（科室）-出院人数统计（科室）');
INSERT INTO `sys_role_permission` VALUES ('512', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '55', '控制台（科室）-质控病历数统计（科室）');
INSERT INTO `sys_role_permission` VALUES ('513', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '56', '控制台（科室）-各模块缺陷占比排行（科室）');
INSERT INTO `sys_role_permission` VALUES ('514', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '57', '控制台（科室）-条目缺陷占比（科室）');
INSERT INTO `sys_role_permission` VALUES ('1164', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '45', null);
INSERT INTO `sys_role_permission` VALUES ('1165', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '46', null);
INSERT INTO `sys_role_permission` VALUES ('1166', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '47', null);
INSERT INTO `sys_role_permission` VALUES ('1167', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '48', null);
INSERT INTO `sys_role_permission` VALUES ('1168', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '49', null);
INSERT INTO `sys_role_permission` VALUES ('1169', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '50', null);
INSERT INTO `sys_role_permission` VALUES ('1170', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '51', null);
INSERT INTO `sys_role_permission` VALUES ('1171', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '52', null);
INSERT INTO `sys_role_permission` VALUES ('1172', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '53', null);
INSERT INTO `sys_role_permission` VALUES ('1173', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '1', null);
INSERT INTO `sys_role_permission` VALUES ('1174', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '2', null);
INSERT INTO `sys_role_permission` VALUES ('1175', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '4', null);
INSERT INTO `sys_role_permission` VALUES ('1176', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '7', null);
INSERT INTO `sys_role_permission` VALUES ('1177', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '17', null);
INSERT INTO `sys_role_permission` VALUES ('1178', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '11', null);
INSERT INTO `sys_role_permission` VALUES ('1179', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '12', null);
INSERT INTO `sys_role_permission` VALUES ('1180', 'N', '2020-05-14 13:31:16', '2020-05-14 13:31:16', '1', '1', '1', '13', null);
INSERT INTO `sys_role_permission` VALUES ('1182', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '59', '控制台-各模块缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1183', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '60', '控制台-条目缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1184', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '61', '异常数据监控-查询异常数据监控信息');
INSERT INTO `sys_role_permission` VALUES ('1185', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '62', '异常数据监控-异常数据监控-查询异常数据监控信息');
INSERT INTO `sys_role_permission` VALUES ('1186', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '63', '异常数据监控-异常数据监控-删除异常数据监控信息');
INSERT INTO `sys_role_permission` VALUES ('1187', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '64', '控制台-科室平均住院天数_详情');
INSERT INTO `sys_role_permission` VALUES ('1188', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '65', '控制台-科室平均住院花费_详情');
INSERT INTO `sys_role_permission` VALUES ('1189', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '66', '控制台-各科室质控平均分_详情');
INSERT INTO `sys_role_permission` VALUES ('1190', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '67', '控制台-各科室缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1191', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '68', '控制台-各科室甲级病历占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1192', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '69', '控制台（科室）-各模块缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1193', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '70', '控制台（科室）-条目缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1194', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '54', null);
INSERT INTO `sys_role_permission` VALUES ('1195', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '55', null);
INSERT INTO `sys_role_permission` VALUES ('1196', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '56', null);
INSERT INTO `sys_role_permission` VALUES ('1197', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '57', null);
INSERT INTO `sys_role_permission` VALUES ('1199', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '1', null);
INSERT INTO `sys_role_permission` VALUES ('1200', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '2', null);
INSERT INTO `sys_role_permission` VALUES ('1201', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '4', null);
INSERT INTO `sys_role_permission` VALUES ('1202', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '7', null);
INSERT INTO `sys_role_permission` VALUES ('1203', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '40', null);
INSERT INTO `sys_role_permission` VALUES ('1204', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '41', null);
INSERT INTO `sys_role_permission` VALUES ('1205', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '42', null);
INSERT INTO `sys_role_permission` VALUES ('1206', 'N', '2020-05-18 10:48:43', '2020-05-18 10:48:43', '1', '1', '3', '43', null);
INSERT INTO `sys_role_permission` VALUES ('1207', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '54', null);
INSERT INTO `sys_role_permission` VALUES ('1208', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '55', null);
INSERT INTO `sys_role_permission` VALUES ('1209', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '56', null);
INSERT INTO `sys_role_permission` VALUES ('1210', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '57', null);
INSERT INTO `sys_role_permission` VALUES ('1212', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '1', null);
INSERT INTO `sys_role_permission` VALUES ('1213', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '2', null);
INSERT INTO `sys_role_permission` VALUES ('1214', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '4', null);
INSERT INTO `sys_role_permission` VALUES ('1215', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '7', null);
INSERT INTO `sys_role_permission` VALUES ('1216', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '34', null);
INSERT INTO `sys_role_permission` VALUES ('1217', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '35', null);
INSERT INTO `sys_role_permission` VALUES ('1218', 'N', '2020-05-18 10:48:51', '2020-05-18 10:48:51', '1', '1', '2', '36', null);
INSERT INTO `sys_role_permission` VALUES ('1219', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '59', '控制台-各模块缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1220', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '60', '控制台-条目缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1221', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '64', '控制台-科室平均住院天数_详情');
INSERT INTO `sys_role_permission` VALUES ('1222', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '65', '控制台-科室平均住院花费_详情');
INSERT INTO `sys_role_permission` VALUES ('1223', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '66', '控制台-各科室质控平均分_详情');
INSERT INTO `sys_role_permission` VALUES ('1224', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '67', '控制台-各科室缺陷占比-缺陷详情');
INSERT INTO `sys_role_permission` VALUES ('1225', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '1', '68', '控制台-各科室甲级病历占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1226', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '2', '69', '控制台（科室）-各模块缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1227', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '2', '70', '控制台（科室）-条目缺陷占比_详情');
INSERT INTO `sys_role_permission` VALUES ('1228', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '71', '控制台-各科室缺陷占比（组合）');
INSERT INTO `sys_role_permission` VALUES ('1229', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '72', '控制台-病案首页合格率占比');
INSERT INTO `sys_role_permission` VALUES ('1230', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '73', '控制台（科室）-各科室缺陷占比（科室）');
INSERT INTO `sys_role_permission` VALUES ('1231', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '74', '控制台（科室）-病案首页合格率占比（科室）');
INSERT INTO `sys_role_permission` VALUES ('1232', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '75', '控制台-病案首页合格率占比（首页）');
INSERT INTO `sys_role_permission` VALUES ('1233', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '76', '控制台（科室）-病案首页合格率占比（首页）');
INSERT INTO `sys_role_permission` VALUES ('1234', 'N', '1970-01-01 12:00:00', '1970-01-01 12:00:00', '0', '0', '-1', '77', '控制台（科室）-科室缺陷占比-缺陷明细');
