package com.diagbot.config.security;

import com.diagbot.facade.TokenFacade;
import com.diagbot.util.HttpUtils;
import com.diagbot.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.AccessDecisionManager;
import org.springframework.security.access.AccessDeniedException;
import org.springframework.security.access.ConfigAttribute;
import org.springframework.security.authentication.AccountExpiredException;
import org.springframework.security.authentication.InsufficientAuthenticationException;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.web.FilterInvocation;
import org.springframework.security.web.util.matcher.AntPathRequestMatcher;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.Collection;

/**
 * @Description: 自定义权限拦截
 * @author: gaodm
 * @time: 2018/8/23 13:46
 */
@Service
public class UrlAccessDecisionManager implements AccessDecisionManager {
    @Autowired
    private TokenFacade tokenFacade;

    @Override
    public void decide(Authentication authentication, Object object, Collection<ConfigAttribute> configAttributes) throws AccessDeniedException, InsufficientAuthenticationException {
        HttpServletRequest request = ((FilterInvocation) object).getHttpRequest();
        String url, method;
        if (matchPermitAllUrl(request)) {
            return;
        }
        if ("anonymousUser".equals(authentication.getPrincipal())) {
            throw new AccessDeniedException("no right");
        } else {
            String tokenStr = HttpUtils.getHeaders(request).get("Authorization");
            if (StringUtil.isNotEmpty(tokenStr)) {
                tokenStr = tokenStr.replaceFirst("Bearer ", "");
                Boolean res = tokenFacade.verifyToken(tokenStr, 1);
                if (!res) {
                    throw new AccountExpiredException("token expire");
                }
            }
            for (GrantedAuthority ga : authentication.getAuthorities()) {
                String[] authority = ga.getAuthority().split(";");
                url = authority[0];
                method = authority[1];
                if (matchers(url, request)) {
                    if (method.equals(request.getMethod()) || "ALL".equals(method)) {
                        return;
                    }
                }
            }
        }
        throw new AccessDeniedException("no right");
    }


    @Override
    public boolean supports(ConfigAttribute attribute) {
        return true;
    }

    @Override
    public boolean supports(Class<?> clazz) {
        return true;
    }

    private Boolean matchPermitAllUrl(HttpServletRequest request) {
        if (matchers("/swagger/**", request)
                || matchers("/v2/**", request)
                || matchers("/swagger-ui.html/**", request)
                || matchers("/swagger-resources/**", request)
                || matchers("/webjars/**", request)
                || matchers("/druid/**", request)
                || matchers("/actuator/**", request)
                || matchers("/hystrix/**", request)
                || matchers("/sys/user/getJwt", request)
                || matchers("/sys/user/getJwtNoPass", request)
                || matchers("/sys/user/refreshJwt", request)
                || matchers("/sys/dictionaryInfo/getDictionary", request)
                || matchers("/sys/user/checkToken", request)
                || matchers("/oauth/token", request)
                || matchers("/oauth/check_token", request)
                || matchers("/cache/clear", request)
                || matchers("/qc/behospitalInfo/execule", request)
                || matchers("/qc/behospitalInfo/analyze_rpc", request)
                || matchers("/qc/behospitalInfo/analyze_api", request)
                || matchers("/qc/behospitalInfo/analyze_run", request)
                || matchers("/qc/module/getById", request)
                || matchers("/qc/module/getModuleMap", request)
                || matchers("/qc/cases/getQcCases", request)
                || matchers("/qc/behospitalInfo/page", request)
                || matchers("/qc/casesEntryHospital/getQcCasesEntryAll", request)
                || matchers("/qc/casesEntryHospital/getQcCasesAll", request)
                || matchers("/qc/behospitalInfo/getByBehospitalCode", request)
                || matchers("/bas/dept/getList", request)
                || matchers("/bas/dept/getListUser", request)
                || matchers("/qc/behospitalInfo/page_dept", request)
                || matchers("/qc/behospitalInfo/page_person", request)
                || matchers("/qc/behospitalInfo/page_group", request)
                || matchers("/qc/casesEntryHospital/findQcCasesEntry", request)
                || matchers("/qc/behospitalInfo/exportExcel", request)
                || matchers("/qc/dataimport/import", request)
                || matchers("/qc/dataimport/test", request)
                || matchers("/qc/behospitalInfo/exportExcel", request)
                || matchers("/qc/behospitalInfo/exportQcresult", request)
                || matchers("/qc/behospitalInfo/exportQcresultByDept", request)
                || matchers("/qc/behospitalInfo/exportQcresultByGroup", request)
                || matchers("/qc/abnormal/getQcAnnormalMode", request)
                || matchers("/qc/dataimport/import", request)
                || matchers("/qc/dataimport/dataimportPrepare", request)
                || matchers("/qc/dataimport/test", request)
                || matchers("/sys/user/pageset/getPageSet", request)
                || matchers("/sys/user/pageset/savePageSet", request)
                || matchers("/sys/user/pageset/getDefaultPageSet", request)
                || matchers("/consoleByDept/getDept", request)
                || matchers("/console/entryRejectPercent", request)
                || matchers("/console/qcResultLevelPercent", request)
                || matchers("/console/averageStatistics", request)
                || matchers("/console/entryByDept", request)
                || matchers("/console/entryCountGroupByCase", request)
                || matchers("/console/entryCountGroupByCasePage", request)
                || matchers("/console/entryCountGroupByEntry", request)
                || matchers("/console/entryCountGroupByEntryPage", request)
                || matchers("/console/entryGroupByEntryInnerPage", request)
                || matchers("/console/getAverageDayNum", request)
                || matchers("/console/getAverageDayNumPage", request)
                || matchers("/console/getAverageFee", request)
                || matchers("/console/getAverageFeePage", request)
                || matchers("/console/getAverageScore", request)
                || matchers("/console/getAverageScoreByDeptClass", request)
                || matchers("/console/getAverageScoreByDeptPage", request)
                || matchers("/console/getLevelResultDept", request)
                || matchers("/console/homePageLevelLimit", request)
                || matchers("/console/homePageLevelStatistics", request)
                || matchers("/console/leaveHosCount", request)
                || matchers("/console/levelPercentGroupByDeptPage", request)
                || matchers("/console/levelStatistics", request)
                || matchers("/console/levelStatisticsByDeptClass", request)
                || matchers("/console/mrCount", request)
                || matchers("/console/mrStatistics", request)
                || matchers("/console/qcResultShortPage", request)
                || matchers("/console/resultStatistics", request)
                || matchers("/console/resultStatisticsByDeptPage", request)
                || matchers("/console/homePageMRCount", request)
                || matchers("/console/qcCheckStatistics", request)
                || matchers("/console/unModifyMRStatistics", request)
                || matchers("/console/unModifyMRPage", request)
                || matchers("/console/reHos31DaysPage", request)
                || matchers("/console/beHosCount", request)
                || matchers("/console/casesEntryStatisticsById", request)
                || matchers("/console/hmImproveMRPage", request)
                || matchers("/console/qcCheckMRPage", request)
                || matchers("/consoleByDept/entryCountGroupByCaseAndDept", request)
                || matchers("/consoleByDept/entryCountGroupByCaseAndDeptPage", request)
                || matchers("/consoleByDept/entryCountGroupByEntryAndDept", request)
                || matchers("/consoleByDept/entryCountGroupByEntryAndDeptPage", request)
                || matchers("/consoleByDept/entryGroupByEntryAndDeptInnerPage", request)
                || matchers("/consoleByDept/homePageLevelByDeptLimit", request)
                || matchers("/consoleByDept/homePageLevelStatisticsByDept", request)
                || matchers("/consoleByDept/leaveHosCountByDept", request)
                || matchers("/consoleByDept/levelStatisticsByDept", request)
                || matchers("/consoleByDept/mrCountByDept", request)
                || matchers("/consoleByDept/qcResultShortByDeptPage", request)
                || matchers("/consoleByDept/resultStatisticsByDeptAndDoctorPage", request)
                || matchers("/console/export/homePageLevelExport", request)
                || matchers("/console/export/entryGroupByEntryExport", request)
                || matchers("/console/export/levelExport", request)
                || matchers("/console/entryStatistics", request)
                || matchers("/console/export/levelExport_TZ", request)
                || matchers("/console/export/getAverageDayNumExport", request)
                || matchers("/console/export/getAverageFeeExport", request)
                || matchers("/console/export/levelPercentGroupByDeptExport", request)
                || matchers("/console/export/entryCountGroupByEntryExport", request)
                || matchers("/console/export/entryCountGroupByCaseExport", request)
                || matchers("/console/export/entryStatisticsExport", request)
                || matchers("/console/export/qcResultShortPageExport", request)
                || matchers("/console/export/leaveHosMrPageExport", request)
                || matchers("/console/export/qcCheckStatisticsExport", request)
                || matchers("/console/export/unModifyMRPageExport", request)
                || matchers("/console/export/unModifyMRStatisticsExport", request)
                || matchers("/console/export/reHos31DaysPageExport", request)
                || matchers("/console/export/hmImproveMRPageExport", request)
                || matchers("/console/export/qcCheckMRPageExport", request)
                || matchers("/qc/data/sendDoctorInfos", request)
                || matchers("/qc/data/sendDeptInfos", request)
                || matchers("/qc/data/sendRecordTypes", request)
                || matchers("/qc/data/sendMrRecordIng", request)
                || matchers("/qc/data/sendMrContent", request)
                || matchers("/qc/data/sendMrRecord", request)
                || matchers("/qc/data/sendPatientInfo", request)
                || matchers("/qc/data/sendDoctorAdvice", request)
                || matchers("/qc/data/sendHomePageIng", request)
                || matchers("/qc/data/sendHomePage", request)
                || matchers("/qc/data/sendHomeDiagnose", request)
                || matchers("/qc/data/sendHomeOperation", request)
                || matchers("/qc/data/sendCrisis", request)
                || matchers("/qc/data/deleteFlag", request)
                || matchers("/qc/data/placeFile", request)
                || matchers("/qc/data/sendLisResults", request)
                || matchers("/qc/data/sendPacsResults", request)
                || matchers("/qc/data/getColumnZhAndCh", request)
                || matchers("/qc/data/analyseRec", request)
                || matchers("/qc/data/hisDataDeal", request)
                || matchers("/qc/data_str/sendAdmissionNote", request)
                || matchers("/qc/data_str/sendBloodResult", request)
                || matchers("/qc/data_str/sendBloodTransfusion", request)
                || matchers("/qc/data_str/sendConsultationApply", request)
                || matchers("/qc/data_str/sendConsultationNote", request)
                || matchers("/qc/data_str/sendConsultationRecord", request)
                || matchers("/qc/data_str/sendConsultationResult", request)
                || matchers("/qc/data_str/sendCrisisNote", request)
                || matchers("/qc/data_str/sendDeathDiscussion", request)
                || matchers("/qc/data_str/sendDeathNote", request)
                || matchers("/qc/data_str/sendDifficultCase", request)
                || matchers("/qc/data_str/sendFirstRecord", request)
                || matchers("/qc/data_str/sendIllCritically", request)
                || matchers("/qc/data_str/sendIllSeriousl", request)
                || matchers("/qc/data_str/sendLeaveHospital", request)
                || matchers("/qc/data_str/sendOperativeFirstRecord", request)
                || matchers("/qc/data_str/sendOperativeNote", request)
                || matchers("/qc/data_str/sendWardRecord", request)
                || matchers("/qc/data_str/sendTransferOutNote", request)
                || matchers("/qc/data_str/sendTransferInNote", request)
                || matchers("/qc/data_str/sendRescueNote", request)
                || matchers("/qc/data_str/sendPeriodConclusion", request)
                || matchers("/qc/data_str/sendPreoperativeDiscussion", request)
                || matchers("/qc/data_str/sendTalkInform", request)
                || matchers("/qc/data_str/sendInformedConsent", request)
                || matchers("/qc/data_str/sendContent", request)
                || matchers("/qc/doctoradvice/getPage", request)
                || matchers("/qc/medPacsInfo/getCheckPage", request)
                || matchers("/qc/medLisInfo/getExaminePage", request)
                || matchers("/qc/behospitalInfo/analyzeCds", request)
                || matchers("/qc/medLisInfo/getExamineSonPage", request)
                || matchers("/console/medicalCheckForm", request)
                || matchers("/console/medicalCheckTitle", request)
                || matchers("/console/export/medicalCheckExport", request)
                || matchers("/console/export/medicalCheckInnerExport", request)
                || matchers("/console/badLevelPage", request)
                || matchers("/console/export/badLevelPagePageExport", request)
                || matchers("/qc/medNurse/getMedNursePage", request)
                || matchers("/qc/behospitalInfo/exportQcresultByPerson", request)
                || matchers("/consoleByDept/beHosCountByDept", request)
                || matchers("/consoleByDept/casesEntryStatisticsByDept", request)
                || matchers("/bas/doctor/getList", request)
                || matchers("/consoleByDept/homePageOrGoodLevelByDept", request)
                || matchers("/print/export/homePageLevelExportByDept", request)
                || matchers("/print/export/homePageOrLevelExportByDept", request)
                || matchers("/print/export/entryGroupExportByDeptPage", request)
                || matchers("/print/export/entryGroupExportByDeptCase", request)
                || matchers("/print/export/entryGroupExportByDeptEntry", request)
                || matchers("/print/export/qcResultShortExportByDeptPage", request)
                || matchers("/print/export/levelExportByDept", request)
                || matchers("/consoleByDept/entryStatisticsByDept", request)
                || matchers("/print/export/entryStatisticsExportByDept", request)
                || matchers("/consoleByDept/leaveHosMRPageByDept", request)
                || matchers("/print/export/leaveHosMrPageExportByDept", request)
                || matchers("/consoleByDept/qcCheckStatisticsByDept", request)
                || matchers("/print/export/qcCheckStaExportByDept", request)
                || matchers("/consoleByDept/qcCheckMRPageByDept", request)
                || matchers("/print/export/qcCheckMRPageExportByDept", request)
                || matchers("/consoleByDept/hmImproveMRPageByDept", request)
                || matchers("/print/export/improveMRExportByDept", request)
                || matchers("/consoleByDept/reHos31DaysPageByDept", request)
                || matchers("/print/export/reHos31DaysPageExportByDept", request)
                || matchers("/consoleByDept/unModifyMRSByDept", request)
                || matchers("/print/export/unModifyMRSExportByDept", request)
                || matchers("/consoleByDept/unModifyMRPageByDept", request)
                || matchers("/print/export/unModifyMRPageExportByDept", request)
                || matchers("/consoleByDept/medicalCheckFormKs", request)
                || matchers("/print/export/medicalCheckExportByDept", request)
                || matchers("/consoleByDept/medicalCheckTitleKs", request)
                || matchers("/console/qualityControl", request)
                || matchers("/console/export/qualityControlExport", request)
                || matchers("/consoleByDept/qualityControlByDept", request)
                || matchers("/print/export/qualityControlExportByDept", request)
                || matchers("/", request)) {
            return true;
        }
        return false;
    }


    private boolean matchers(String url, HttpServletRequest request) {
        AntPathRequestMatcher matcher = new AntPathRequestMatcher(url);
        if (matcher.matches(request)) {
            return true;
        }
        return false;
    }
}
