package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrConsultationNote;
import com.diagbot.entity.StrConsultationNote;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrConsultationNoteServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrConsultationNoteVO;
import com.diagbot.vo.str.StrConsultationNoteVO;
import com.diagbot.vo.str.StrContentVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrConsultationNoteFacade extends StrConsultationNoteServiceImpl {

    @Autowired
    @Qualifier("strConsultationNoteServiceImpl")
    private StrConsultationNoteServiceImpl strConsultationNoteService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap=EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strConsultationNote");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrConsultationNote strConsultationNote=new StrConsultationNote();
        strConsultationNote.setRecId(strContentVO.getRecId());
        strConsultationNote.setBehospitalCode(strContentVO.getBehospitalCode());
        strConsultationNote.setHospitalId(strContentVO.getHospitalId());
        strConsultationNote.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strConsultationNote)) {
            strConsultationNote.setGmtCreate(new Date());//记录创建时间
            this.save(strConsultationNote);
        } else {
            strConsultationNote.setGmtModified(new Date());//记录修改时间
            this.update(strConsultationNote, new QueryWrapper<StrConsultationNote>()
                    .eq("rec_id", strConsultationNote.getRecId())
                    .eq("hospital_id", strConsultationNote.getHospitalId())
                    .eq("behospital_code", strConsultationNote.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrConsultationNote strConsultationNote=new StrConsultationNote();
        try {
            AStrConsultationNoteVO strConsultationNoteVO=(AStrConsultationNoteVO) MapUtil.mapToObject(entityMap, AStrConsultationNoteVO.class);
            BeanUtils.copyProperties(strConsultationNoteVO,strConsultationNote);
            strConsultationNote.setHospitalId(hospitalId);//医院编码

            strConsultationNote.setAuditDate(DateUtil.parseDateTime(strConsultationNoteVO.getAuditDate()));//审核时间
            strConsultationNote.setRecDate(DateUtil.parseDateTime(strConsultationNoteVO.getRecDate()));//记录时间
            strConsultationNote.setBehospitalDate(DateUtil.parseDateTime(strConsultationNoteVO.getBehospitalDate()));//入院日期
            strConsultationNote.setApplyDate(DateUtil.parseDate(strConsultationNoteVO.getApplyDate()));//申请日期
            strConsultationNote.setRecordDate(DateUtil.parseDateTime(strConsultationNoteVO.getRecordDate()));//病历日期
            strConsultationNote.setConsultationDate(DateUtil.parseDateTime(strConsultationNoteVO.getConsultationDate()));//会诊时间

            strConsultationNote.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strConsultationNote)){
                strConsultationNote.setGmtCreate(new Date());//记录创建时间
                this.save(strConsultationNote);
            }else{
                strConsultationNote.setGmtModified(new Date());//记录修改时间
                this.update(strConsultationNote,new QueryWrapper<StrConsultationNote>()
                        .eq("rec_id", strConsultationNote.getRecId())
                        .eq("hospital_id", strConsultationNote.getHospitalId())
                        .eq("behospital_code", strConsultationNote.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("会诊单（申请和结果）",strConsultationNote.getRecId(), JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrConsultationNote strConsultationNote){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrConsultationNote>()
                .eq("rec_id", strConsultationNote.getRecId())
                .eq("hospital_id", strConsultationNote.getHospitalId())
                .eq("behospital_code", strConsultationNote.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:会诊单（申请和结果）-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrConsultationNoteVO> list){
        try {
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrConsultationNoteVO strConsultationNoteVO:list) {
                    if("".equals(strConsultationNoteVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strConsultationNoteVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strConsultationNoteVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrConsultationNote> strConsultationNoteList= initData(list);
                execute(strConsultationNoteList);

                if(logSwitch){
                    strConsultationNoteList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-会诊单（申请和结果）-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
            list.forEach(s->{
            aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-会诊单（申请和结果）-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
            });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrConsultationNote> initData(List<StrConsultationNoteVO> list) throws Exception{
        List<StrConsultationNote> tList=Lists.newArrayList();
        for (StrConsultationNoteVO s:list) {
            StrConsultationNote t=new StrConsultationNote();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getBehospitalDate())){
                t.setBehospitalDate(DateUtil.parseDateTime(s.getBehospitalDate()));//入院日期
            }
            if(StringUtil.isNotEmpty(s.getApplyDate())){
                t.setApplyDate(DateUtil.parseDateTime(s.getApplyDate()));//申请日期
            }
            if(StringUtil.isNotEmpty(s.getConsultationDate())){
                t.setConsultationDate(DateUtil.parseDateTime(s.getConsultationDate()));//会诊时间
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.CONSULTATION_NOTE.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrConsultationNote> list) throws Exception{
        List<StrConsultationNote> addE = Lists.newLinkedList();
        List<StrConsultationNote> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrConsultationNote strConsultationNote = this.getOne(new QueryWrapper<StrConsultationNote>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strConsultationNote != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strConsultationNoteService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }

}
