package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrConsultationRecord;
import com.diagbot.entity.StrConsultationRecord;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrConsultationRecordServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.AStrConsultationRecordVO;
import com.diagbot.vo.str.StrConsultationRecordVO;
import com.diagbot.vo.str.StrContentVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;
@Component
public class BStrConsultationRecordFacade extends StrConsultationRecordServiceImpl {

    @Autowired
    @Qualifier("strConsultationRecordServiceImpl")
    private StrConsultationRecordServiceImpl strConsultationRecordService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strConsultationRecord");

        //Map<String, String> map=columnFacade.getColumn("strConsultationRecord");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrConsultationRecord strConsultationRecord=new StrConsultationRecord();
        strConsultationRecord.setRecId(strContentVO.getRecId());
        strConsultationRecord.setBehospitalCode(strContentVO.getBehospitalCode());
        strConsultationRecord.setHospitalId(strContentVO.getHospitalId());
        strConsultationRecord.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strConsultationRecord)) {
            strConsultationRecord.setGmtCreate(new Date());//记录创建时间
            this.save(strConsultationRecord);
        } else {
            strConsultationRecord.setGmtModified(new Date());//记录修改时间
            this.update(strConsultationRecord, new QueryWrapper<StrConsultationRecord>()
                    .eq("rec_id", strConsultationRecord.getRecId())
                    .eq("hospital_id", strConsultationRecord.getHospitalId())
                    .eq("behospital_code", strConsultationRecord.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrConsultationRecord strConsultationRecord=new StrConsultationRecord();
        try {
            AStrConsultationRecordVO AStrConsultationRecordVO=(AStrConsultationRecordVO) MapUtil.mapToObject(entityMap, AStrConsultationRecordVO.class);
            BeanUtils.copyProperties(AStrConsultationRecordVO,strConsultationRecord);
            strConsultationRecord.setHospitalId(hospitalId);//医院编码

            strConsultationRecord.setRecordDate(DateUtil.parseDateTime(AStrConsultationRecordVO.getRecordDate()));//病历日期recordDate
            strConsultationRecord.setBehospitalDate(DateUtil.parseDateTime(AStrConsultationRecordVO.getBehospitalDate()));//入院日期behospital_date
            strConsultationRecord.setApplyDate(DateUtil.parseDateTime(AStrConsultationRecordVO.getApplyDate()));//申请日期apply_date
            strConsultationRecord.setConsultationDate(DateUtil.parseDate(AStrConsultationRecordVO.getConsultationArriveDate()));//会诊时间consultation_date
            strConsultationRecord.setRecDate(DateUtil.parseDateTime(AStrConsultationRecordVO.getRecDate()));//记录时间rec_date
            strConsultationRecord.setAuditDate(DateUtil.parseDateTime(AStrConsultationRecordVO.getAuditDate()));//审核时间audit_date

            strConsultationRecord.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strConsultationRecord)){
                strConsultationRecord.setGmtCreate(new Date());//记录创建时间
                this.save(strConsultationRecord);
            }else{
                strConsultationRecord.setGmtModified(new Date());//记录修改时间
                this.update(strConsultationRecord,new QueryWrapper<StrConsultationRecord>()
                        .eq("rec_id", strConsultationRecord.getRecId())
                        .eq("hospital_id", strConsultationRecord.getHospitalId())
                        .eq("behospital_code", strConsultationRecord.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("会诊记录）",strConsultationRecord.getRecId(), JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrConsultationRecord strConsultationRecord){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrConsultationRecord>()
                .eq("rec_id", strConsultationRecord.getRecId())
                .eq("hospital_id", strConsultationRecord.getHospitalId())
                .eq("behospital_code", strConsultationRecord.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:会诊记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrConsultationRecordVO> list){
        try {
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrConsultationRecordVO strConsultationRecordVO:list) {
                    if("".equals(strConsultationRecordVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strConsultationRecordVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strConsultationRecordVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrConsultationRecord> strConsultationRecordList= initData(list);
                execute(strConsultationRecordList);

                if(logSwitch){
                    strConsultationRecordList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-会诊记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-会诊记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrConsultationRecord> initData(List<StrConsultationRecordVO> list) throws Exception{
        List<StrConsultationRecord> tList=Lists.newArrayList();
        for (StrConsultationRecordVO s:list) {
            StrConsultationRecord t=new StrConsultationRecord();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getBehospitalDate())){
                t.setBehospitalDate(DateUtil.parseDateTime(s.getBehospitalDate()));//入院日期
            }
            if(StringUtil.isNotEmpty(s.getApplyDate())){
                t.setApplyDate(DateUtil.parseDateTime(s.getApplyDate()));//申请日期
            }
            if(StringUtil.isNotEmpty(s.getConsultationDate())){
                t.setConsultationDate(DateUtil.parseDateTime(s.getConsultationDate()));//会诊时间
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.CONSULTATION_RECORD.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrConsultationRecord> list){
        List<StrConsultationRecord> addE = Lists.newLinkedList();
        List<StrConsultationRecord> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrConsultationRecord strConsultationRecord = this.getOne(new QueryWrapper<StrConsultationRecord>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strConsultationRecord != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strConsultationRecordService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
