package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrConsultationResult;
import com.diagbot.entity.StrConsultationResult;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrConsultationResultServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrConsultationResultVO;
import com.diagbot.vo.str.StrConsultationResultVO;
import com.diagbot.vo.str.StrContentVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Description:会诊结果单-业务类
 * @Author:liuqq
 * @time: ${DATE} ${TIME}
 **/
@Component
public class BStrConsultationResultFacade extends StrConsultationResultServiceImpl {

    @Autowired
    @Qualifier("strConsultationResultServiceImpl")
    private StrConsultationResultServiceImpl strConsultationResultService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strConsultationResult");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrConsultationResult strConsultationResult=new StrConsultationResult();
        strConsultationResult.setRecId(strContentVO.getRecId());
        strConsultationResult.setBehospitalCode(strContentVO.getBehospitalCode());
        strConsultationResult.setHospitalId(strContentVO.getHospitalId());
        strConsultationResult.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strConsultationResult)) {
            strConsultationResult.setGmtCreate(new Date());//记录创建时间
            this.save(strConsultationResult);
        } else {
            strConsultationResult.setGmtModified(new Date());//记录修改时间
            this.update(strConsultationResult, new QueryWrapper<StrConsultationResult>()
                    .eq("rec_id", strConsultationResult.getRecId())
                    .eq("hospital_id", strConsultationResult.getHospitalId())
                    .eq("behospital_code", strConsultationResult.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrConsultationResult strConsultationResult=new StrConsultationResult();
        try {
            AStrConsultationResultVO strConsultationResultVO=(AStrConsultationResultVO) MapUtil.mapToObject(entityMap, AStrConsultationResultVO.class);
            BeanUtils.copyProperties(strConsultationResultVO,strConsultationResult);
            strConsultationResult.setHospitalId(hospitalId);//医院编码

            strConsultationResult.setAuditDate(DateUtil.parseDateTime(strConsultationResultVO.getAuditDate()));//审核时间
            strConsultationResult.setRecDate(DateUtil.parseDateTime(strConsultationResultVO.getRecDate()));//记录时间
            strConsultationResult.setBehospitalDate(DateUtil.parseDateTime(strConsultationResultVO.getBehospitalDate()));//入院日期
            strConsultationResult.setApplyDate(DateUtil.parseDate(strConsultationResultVO.getApplyDate()));//申请时间
            strConsultationResult.setRecordDate(DateUtil.parseDateTime(strConsultationResultVO.getRecordDate()));//病历日期
            strConsultationResult.setConsultationArriveDate(DateUtil.parseDateTime(strConsultationResultVO.getConsultationArriveDate()));//会诊到达时间

            strConsultationResult.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strConsultationResult)){
                strConsultationResult.setGmtCreate(new Date());//记录创建时间
                this.save(strConsultationResult);
            }else{
                strConsultationResult.setGmtModified(new Date());//记录修改时间
                this.update(strConsultationResult,new QueryWrapper<StrConsultationResult>()
                        .eq("rec_id", strConsultationResult.getRecId())
                        .eq("hospital_id", strConsultationResult.getHospitalId())
                        .eq("behospital_code", strConsultationResult.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("会诊结果单",strConsultationResult.getRecId(), JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrConsultationResult strConsultationResult){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrConsultationResult>()
                .eq("rec_id", strConsultationResult.getRecId())
                .eq("hospital_id", strConsultationResult.getHospitalId())
                .eq("behospital_code", strConsultationResult.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:会诊结果单-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrConsultationResultVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrConsultationResultVO strConsultationResultVO:list) {
                    if("".equals(strConsultationResultVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strConsultationResultVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strConsultationResultVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrConsultationResult> strConsultationResultList= initData(list);
                execute(strConsultationResultList);

                if(logSwitch){
                    strConsultationResultList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-会诊结果单-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-会诊结果单-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrConsultationResult> initData(List<StrConsultationResultVO> list) throws Exception{
        List<StrConsultationResult> tList=Lists.newArrayList();
        for (StrConsultationResultVO s:list) {
            StrConsultationResult t=new StrConsultationResult();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getBehospitalDate())){
                t.setBehospitalDate(DateUtil.parseDateTime(s.getBehospitalDate()));//入院日期
            }
            if(StringUtil.isNotEmpty(s.getApplyDate())){
                t.setApplyDate(DateUtil.parseDateTime(s.getApplyDate()));//申请日期
            }
            if(StringUtil.isNotEmpty(s.getConsultationArriveDate())){
                t.setConsultationArriveDate(DateUtil.parseDateTime(s.getConsultationArriveDate()));//会诊到达时间
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.CONSULTATION_RESULT.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrConsultationResult> list){
        List<StrConsultationResult> addE = Lists.newLinkedList();
        List<StrConsultationResult> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrConsultationResult strConsultationResult = this.getOne(new QueryWrapper<StrConsultationResult>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strConsultationResult != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strConsultationResultService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
