package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrCrisisNote;
import com.diagbot.entity.StrCrisisNote;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrCrisisNoteServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrCrisisNoteVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrCrisisNoteVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrCrisisNoteFacade extends StrCrisisNoteServiceImpl {

    @Autowired
    @Qualifier("strCrisisNoteServiceImpl")
    private StrCrisisNoteServiceImpl strCrisisNoteService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;

    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strCrisisNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrCrisisNote strCrisisNote=new StrCrisisNote();
        strCrisisNote.setRecId(strContentVO.getRecId());
        strCrisisNote.setBehospitalCode(strContentVO.getBehospitalCode());
        strCrisisNote.setHospitalId(strContentVO.getHospitalId());
        strCrisisNote.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strCrisisNote)) {
            strCrisisNote.setGmtCreate(new Date());//记录创建时间
            this.save(strCrisisNote);
        } else {
            strCrisisNote.setGmtModified(new Date());//记录修改时间
            this.update(strCrisisNote, new QueryWrapper<StrCrisisNote>()
                    .eq("rec_id", strCrisisNote.getRecId())
                    .eq("hospital_id", strCrisisNote.getHospitalId())
                    .eq("behospital_code", strCrisisNote.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrCrisisNote strCrisisNote=new StrCrisisNote();
        try {
            AStrCrisisNoteVO strCrisisNoteVO=(AStrCrisisNoteVO) MapUtil.mapToObject(entityMap, AStrCrisisNoteVO.class);
            BeanUtils.copyProperties(strCrisisNoteVO,strCrisisNote);
            strCrisisNote.setHospitalId(hospitalId);//医院编码

            strCrisisNote.setAuditDate(DateUtil.parseDateTime(strCrisisNoteVO.getAuditDate()));//审核时间
            strCrisisNote.setRecDate(DateUtil.parseDateTime(strCrisisNoteVO.getRecDate()));//记录时间
            strCrisisNote.setRecieveDate(DateUtil.parseDateTime(strCrisisNoteVO.getRecieveDate()));//开始时间
            strCrisisNote.setAuditDate(DateUtil.parseDate(strCrisisNoteVO.getAuditDate()));//结束时间
            strCrisisNote.setRecordDate(DateUtil.parseDateTime(strCrisisNoteVO.getRecordDate()));//病历日期

            strCrisisNote.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strCrisisNote)){
                strCrisisNote.setGmtCreate(new Date());//记录创建时间
                this.save(strCrisisNote);
            }else{
                strCrisisNote.setGmtModified(new Date());//记录修改时间
                this.update(strCrisisNote,new QueryWrapper<StrCrisisNote>()
                        .eq("rec_id", strCrisisNote.getRecId())
                        .eq("hospital_id", strCrisisNote.getHospitalId())
                        .eq("behospital_code", strCrisisNote.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("危急值记录",strCrisisNote.getRecId(), JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrCrisisNote strCrisisNote){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrCrisisNote>()
                .eq("rec_id", strCrisisNote.getRecId())
                .eq("hospital_id", strCrisisNote.getHospitalId())
                .eq("behospital_code", strCrisisNote.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:危急值记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrCrisisNoteVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrCrisisNoteVO strCrisisNoteVO:list) {
                    if("".equals(strCrisisNoteVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strCrisisNoteVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strCrisisNoteVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrCrisisNote> strCrisisNoteList= initData(list);
                execute(strCrisisNoteList);

                if(logSwitch){
                    strCrisisNoteList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-危急值记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-危急值记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrCrisisNote> initData(List<StrCrisisNoteVO> list) throws Exception{
        List<StrCrisisNote> tList=Lists.newArrayList();
        for (StrCrisisNoteVO s:list) {
            StrCrisisNote t=new StrCrisisNote();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getRecieveDate())){
                t.setRecieveDate(DateUtil.parseDateTime(s.getRecieveDate()));//接收日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.CRISIS_NOTE.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrCrisisNote> list){
        List<StrCrisisNote> addE = Lists.newLinkedList();
        List<StrCrisisNote> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrCrisisNote strCrisisNote = this.getOne(new QueryWrapper<StrCrisisNote>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strCrisisNote != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strCrisisNoteService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
