package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrDeathNote;
import com.diagbot.entity.StrDeathNote;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrDeathNoteServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrDeathNoteVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrDeathNoteVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrDeathNoteFacade extends StrDeathNoteServiceImpl {

    @Autowired
    @Qualifier("strDeathNoteServiceImpl")
    private StrDeathNoteServiceImpl strDeathNoteService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strDeathNote");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrDeathNote strDeathNote=new StrDeathNote();
        strDeathNote.setRecId(strContentVO.getRecId());
        strDeathNote.setBehospitalCode(strContentVO.getBehospitalCode());
        strDeathNote.setHospitalId(strContentVO.getHospitalId());
        strDeathNote.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strDeathNote)) {
            strDeathNote.setGmtCreate(new Date());//记录创建时间
            this.save(strDeathNote);
        } else {
            strDeathNote.setGmtModified(new Date());//记录修改时间
            this.update(strDeathNote, new QueryWrapper<StrDeathNote>()
                    .eq("rec_id", strDeathNote.getRecId())
                    .eq("hospital_id", strDeathNote.getHospitalId())
                    .eq("behospital_code", strDeathNote.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrDeathNote strDeathNote=new StrDeathNote();
        try {
            AStrDeathNoteVO strDeathNoteVO=(AStrDeathNoteVO) MapUtil.mapToObject(entityMap, AStrDeathNoteVO.class);
            BeanUtils.copyProperties(strDeathNoteVO,strDeathNote);
            strDeathNote.setHospitalId(hospitalId);//医院编码

            strDeathNote.setAuditDate(DateUtil.parseDateTime(strDeathNoteVO.getAuditDate()));//审核时间
            strDeathNote.setRecDate(DateUtil.parseDateTime(strDeathNoteVO.getRecDate()));//记录时间
            strDeathNote.setBehospitalDate(DateUtil.parseDateTime(strDeathNoteVO.getBehospitalDate()));//入院日期
            strDeathNote.setDeathDate(DateUtil.parseDate(strDeathNoteVO.getDeathDate()));//死亡日期
            strDeathNote.setRecordDate(DateUtil.parseDateTime(strDeathNoteVO.getRecordDate()));//病历日期

            strDeathNote.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strDeathNote)){
                strDeathNote.setGmtCreate(new Date());//记录创建时间
                this.save(strDeathNote);
            }else{
                strDeathNote.setGmtModified(new Date());//记录修改时间
                this.update(strDeathNote,new QueryWrapper<StrDeathNote>()
                        .eq("rec_id", strDeathNote.getRecId())
                        .eq("hospital_id", strDeathNote.getHospitalId())
                        .eq("behospital_code", strDeathNote.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("死亡记录", strDeathNote.getRecId(),JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrDeathNote strDeathNote){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrDeathNote>()
                .eq("rec_id", strDeathNote.getRecId())
                .eq("hospital_id", strDeathNote.getHospitalId())
                .eq("behospital_code", strDeathNote.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:死亡记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrDeathNoteVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrDeathNoteVO strDeathNoteVO:list) {
                    if("".equals(strDeathNoteVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strDeathNoteVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strDeathNoteVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrDeathNote> strDeathNoteList= initData(list);
                execute(strDeathNoteList);

                if(logSwitch){
                    strDeathNoteList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-死亡记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-死亡记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrDeathNote> initData(List<StrDeathNoteVO> list) throws Exception{
        List<StrDeathNote> tList=Lists.newArrayList();
        for (StrDeathNoteVO s:list) {
            StrDeathNote t=new StrDeathNote();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getDeathDate())){
                t.setDeathDate(DateUtil.parseDateTime(s.getDeathDate()));//死亡日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.DEATH_NOTE.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrDeathNote> list){
        List<StrDeathNote> addE = Lists.newLinkedList();
        List<StrDeathNote> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrDeathNote strDeathNote = this.getOne(new QueryWrapper<StrDeathNote>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strDeathNote != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strDeathNoteService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
