package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrDifficultCase;
import com.diagbot.entity.StrDifficultCase;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrDifficultCaseServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrDifficultCaseVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrDifficultCaseVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrDifficultCaseFacade extends StrDifficultCaseServiceImpl{

    @Autowired
    @Qualifier("strDifficultCaseServiceImpl")
    private StrDifficultCaseServiceImpl strDifficultCaseService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strDifficultCase");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrDifficultCase medDifficult=new StrDifficultCase();
        medDifficult.setRecId(strContentVO.getRecId());
        medDifficult.setBehospitalCode(strContentVO.getBehospitalCode());
        medDifficult.setHospitalId(strContentVO.getHospitalId());
        medDifficult.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(medDifficult)) {
            medDifficult.setGmtCreate(new Date());//记录创建时间
            this.save(medDifficult);
        } else {
            medDifficult.setGmtModified(new Date());//记录修改时间
            this.update(medDifficult, new QueryWrapper<StrDifficultCase>()
                    .eq("rec_id", medDifficult.getRecId())
                    .eq("hospital_id", medDifficult.getHospitalId())
                    .eq("behospital_code", medDifficult.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrDifficultCase medDifficult=new StrDifficultCase();
        try {
            AStrDifficultCaseVO medDifficultVO=(AStrDifficultCaseVO) MapUtil.mapToObject(entityMap, AStrDifficultCaseVO.class);
            BeanUtils.copyProperties(medDifficultVO,medDifficult);
            medDifficult.setHospitalId(hospitalId);//医院编码
            medDifficult.setRecDate(DateUtil.parseDateTime(medDifficultVO.getRecDate()));
            medDifficult.setAuditDate(DateUtil.parseDateTime(medDifficultVO.getAuditDate()));
            medDifficult.setDiscussDate(DateUtil.parseDateTime(medDifficultVO.getDiscussDate()));
            medDifficult.setRecordDate(DateUtil.parseDateTime(medDifficultVO.getRecordDate()));//病历日期

            medDifficult.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(medDifficult)){
                medDifficult.setGmtCreate(new Date());//记录创建时间
                this.save(medDifficult);
            }else{
                medDifficult.setGmtModified(new Date());//记录修改时间
                this.update(medDifficult,new QueryWrapper<StrDifficultCase>()
                        .eq("rec_id", medDifficult.getRecId())
                        .eq("hospital_id", medDifficult.getHospitalId())
                        .eq("behospital_code", medDifficult.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("疑难病例讨论记录",medDifficult.getRecId(), JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrDifficultCase medDifficult){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrDifficultCase>()
                .eq("rec_id", medDifficult.getRecId())
                .eq("hospital_id", medDifficult.getHospitalId())
                .eq("behospital_code", medDifficult.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:疑难病例讨论记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrDifficultCaseVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrDifficultCaseVO strDifficultCaseVO:list) {
                    if("".equals(strDifficultCaseVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strDifficultCaseVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strDifficultCaseVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrDifficultCase> strDifficultCaseList= initData(list);
                execute(strDifficultCaseList);

                if(logSwitch){
                    strDifficultCaseList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-疑难病例讨论记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-疑难病例讨论记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrDifficultCase> initData(List<StrDifficultCaseVO> list) throws Exception{
        List<StrDifficultCase> tList=Lists.newArrayList();
        for (StrDifficultCaseVO s:list) {
            StrDifficultCase t=new StrDifficultCase();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getDiscussDate())){
                t.setDiscussDate(DateUtil.parseDateTime(s.getDiscussDate()));//讨论日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.DIFFICULT_CASE.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrDifficultCase> list){
        List<StrDifficultCase> addE = Lists.newLinkedList();
        List<StrDifficultCase> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrDifficultCase strDifficultCase = this.getOne(new QueryWrapper<StrDifficultCase>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strDifficultCase != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strDifficultCaseService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
