package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrFirstRecord;
import com.diagbot.entity.StrFirstRecord;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrFirstRecordServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrFirstRecordVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrFirstRecordVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrFirstRecordFacade extends StrFirstRecordServiceImpl {

    @Autowired
    @Qualifier("strFirstRecordServiceImpl")
    private StrFirstRecordServiceImpl strFirstRecordService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strFirstRecord");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrFirstRecord medDifficult=new StrFirstRecord();
        medDifficult.setRecId(strContentVO.getRecId());
        medDifficult.setBehospitalCode(strContentVO.getBehospitalCode());
        medDifficult.setHospitalId(strContentVO.getHospitalId());
        medDifficult.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(medDifficult)) {
            medDifficult.setGmtCreate(new Date());//记录创建时间
            this.save(medDifficult);
        } else {
            medDifficult.setGmtModified(new Date());//记录修改时间
            this.update(medDifficult, new QueryWrapper<StrFirstRecord>()
                    .eq("rec_id", medDifficult.getRecId())
                    .eq("hospital_id", medDifficult.getHospitalId())
                    .eq("behospital_code", medDifficult.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrFirstRecord strFirstRecord=new StrFirstRecord();
        try {
            AStrFirstRecordVO strFirstRecordVO=(AStrFirstRecordVO) MapUtil.mapToObject(entityMap, AStrFirstRecordVO.class);
            BeanUtils.copyProperties(strFirstRecordVO,strFirstRecord);
            strFirstRecord.setHospitalId(hospitalId);//医院编码

            strFirstRecord.setAuditDate(DateUtil.parseDateTime(strFirstRecordVO.getAuditDate()));//审核时间
            strFirstRecord.setRecDate(DateUtil.parseDateTime(strFirstRecordVO.getRecDate()));//记录时间
            strFirstRecord.setRecordDate(DateUtil.parseDateTime(strFirstRecordVO.getRecordDate()));//病历日期

            strFirstRecord.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strFirstRecord)){
                strFirstRecord.setGmtCreate(new Date());//记录创建时间
                this.save(strFirstRecord);
            }else{
                strFirstRecord.setGmtModified(new Date());//记录修改时间
                this.update(strFirstRecord,new QueryWrapper<StrFirstRecord>()
                        .eq("rec_id", strFirstRecord.getRecId())
                        .eq("hospital_id", strFirstRecord.getHospitalId())
                        .eq("behospital_code", strFirstRecord.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("首次病程录", strFirstRecord.getRecId(),JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrFirstRecord strFirstRecord){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrFirstRecord>()
                .eq("rec_id", strFirstRecord.getRecId())
                .eq("hospital_id", strFirstRecord.getHospitalId())
                .eq("behospital_code", strFirstRecord.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:首次病程录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrFirstRecordVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrFirstRecordVO strFirstRecordVO:list) {
                    if("".equals(strFirstRecordVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strFirstRecordVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strFirstRecordVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrFirstRecord> strFirstRecordList= initData(list);
                execute(strFirstRecordList);

                if(logSwitch){
                    strFirstRecordList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-首次病程录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-首次病程录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrFirstRecord> initData(List<StrFirstRecordVO> list) throws Exception{
        List<StrFirstRecord> tList=Lists.newArrayList();
        for (StrFirstRecordVO s:list) {
            StrFirstRecord t=new StrFirstRecord();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.FIRST_RECORD.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrFirstRecord> list){
        List<StrFirstRecord> addE = Lists.newLinkedList();
        List<StrFirstRecord> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrFirstRecord strFirstRecord = this.getOne(new QueryWrapper<StrFirstRecord>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strFirstRecord != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strFirstRecordService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
