package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrIllCritically;
import com.diagbot.entity.StrIllCritically;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrIllCriticallyServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrIllCriticallyVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrIllCriticallyVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrIllCriticallyFacade extends StrIllCriticallyServiceImpl {

    @Autowired
    @Qualifier("strIllCriticallyServiceImpl")
    private StrIllCriticallyServiceImpl strIllCriticallyService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strIllCritically");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrIllCritically strIllCritically=new StrIllCritically();
        strIllCritically.setRecId(strContentVO.getRecId());
        strIllCritically.setBehospitalCode(strContentVO.getBehospitalCode());
        strIllCritically.setHospitalId(strContentVO.getHospitalId());
        strIllCritically.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strIllCritically)) {
            strIllCritically.setGmtCreate(new Date());//记录创建时间
            this.save(strIllCritically);
        } else {
            strIllCritically.setGmtModified(new Date());//记录修改时间
            this.update(strIllCritically, new QueryWrapper<StrIllCritically>()
                    .eq("rec_id", strIllCritically.getRecId())
                    .eq("hospital_id", strIllCritically.getHospitalId())
                    .eq("behospital_code", strIllCritically.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrIllCritically strIllCritically=new StrIllCritically();
        try {
            AStrIllCriticallyVO strIllCriticallyVO=(AStrIllCriticallyVO) MapUtil.mapToObject(entityMap, AStrIllCriticallyVO.class);
            BeanUtils.copyProperties(strIllCriticallyVO,strIllCritically);
            strIllCritically.setHospitalId(hospitalId);//医院编码
            strIllCritically.setPatientSignDate(DateUtil.parseDateTime(strIllCriticallyVO.getPatientSignDate()));
            strIllCritically.setDoctorSignDate(DateUtil.parseDateTime(strIllCriticallyVO.getDoctorSignDate()));//审核时间
            strIllCritically.setRecordDate(DateUtil.parseDateTime(strIllCriticallyVO.getRecordDate()));//病历日期

            strIllCritically.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strIllCritically)){
                strIllCritically.setGmtCreate(new Date());//记录创建时间
                this.save(strIllCritically);
            }else{
                strIllCritically.setGmtModified(new Date());//记录修改时间
                this.update(strIllCritically,new QueryWrapper<StrIllCritically>()
                        .eq("rec_id", strIllCritically.getRecId())
                        .eq("hospital_id", strIllCritically.getHospitalId())
                        .eq("behospital_code", strIllCritically.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("病危通知单",strIllCritically.getRecId(), JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrIllCritically strIllCritically){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrIllCritically>()
                .eq("rec_id", strIllCritically.getRecId())
                .eq("hospital_id", strIllCritically.getHospitalId())
                .eq("behospital_code", strIllCritically.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:病危通知单-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrIllCriticallyVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrIllCriticallyVO strIllCriticallyVO:list) {
                    if("".equals(strIllCriticallyVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strIllCriticallyVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strIllCriticallyVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrIllCritically> strIllCriticallyList= initData(list);
                execute(strIllCriticallyList);

                if(logSwitch){
                    strIllCriticallyList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-病危通知单-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-病危通知单-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrIllCritically> initData(List<StrIllCriticallyVO> list) throws Exception{
        List<StrIllCritically> tList=Lists.newArrayList();
        for (StrIllCriticallyVO s:list) {
            StrIllCritically t=new StrIllCritically();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getPatientSignDate())){
                t.setPatientSignDate(DateUtil.parseDateTime(s.getPatientSignDate()));//病人签名日期
            }
            if(StringUtil.isNotEmpty(s.getDoctorSignDate())){
                t.setDoctorSignDate(DateUtil.parseDateTime(s.getDoctorSignDate()));//医生签名日期
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.ILL_CRITICALLY.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrIllCritically> list){
        List<StrIllCritically> addE = Lists.newLinkedList();
        List<StrIllCritically> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrIllCritically strIllCritically = this.getOne(new QueryWrapper<StrIllCritically>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strIllCritically != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strIllCriticallyService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
