package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrLeaveHospital;
import com.diagbot.entity.StrLeaveHospital;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrLeaveHospitalServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrLeaveHospitalVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrLeaveHospitalVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrLeaveHospitalFacade extends StrLeaveHospitalServiceImpl {

    @Autowired
    @Qualifier("strLeaveHospitalServiceImpl")
    private StrLeaveHospitalServiceImpl strLeaveHospitalService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strLeaveHospital");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrLeaveHospital strLeaveHospital=new StrLeaveHospital();
        strLeaveHospital.setRecId(strContentVO.getRecId());
        strLeaveHospital.setBehospitalCode(strContentVO.getBehospitalCode());
        strLeaveHospital.setHospitalId(strContentVO.getHospitalId());
        strLeaveHospital.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strLeaveHospital)) {
            strLeaveHospital.setGmtCreate(new Date());//记录创建时间
            this.save(strLeaveHospital);
        } else {
            strLeaveHospital.setGmtModified(new Date());//记录修改时间
            this.update(strLeaveHospital, new QueryWrapper<StrLeaveHospital>()
                    .eq("rec_id", strLeaveHospital.getRecId())
                    .eq("hospital_id", strLeaveHospital.getHospitalId())
                    .eq("behospital_code", strLeaveHospital.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrLeaveHospital strLeaveHospital=new StrLeaveHospital();
        try {
            AStrLeaveHospitalVO strLeaveHospitalVO=(AStrLeaveHospitalVO) MapUtil.mapToObject(entityMap, AStrLeaveHospitalVO.class);
            BeanUtils.copyProperties(strLeaveHospitalVO,strLeaveHospital);
            strLeaveHospital.setHospitalId(hospitalId);//医院编码

            strLeaveHospital.setAuditDate(DateUtil.parseDateTime(strLeaveHospitalVO.getAuditDate()));//审核时间
            strLeaveHospital.setRecDate(DateUtil.parseDateTime(strLeaveHospitalVO.getRecDate()));//记录时间
            strLeaveHospital.setBehospitalDate(DateUtil.parseDateTime(strLeaveHospitalVO.getBehospitalDate()));//入院日期
            strLeaveHospital.setLeaveHospitalDate(DateUtil.parseDateTime(strLeaveHospitalVO.getLeaveHospitalDate()));//出院时间
            strLeaveHospital.setRecordDate(DateUtil.parseDateTime(strLeaveHospitalVO.getRecordDate()));//病历日期

            strLeaveHospital.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strLeaveHospital)){
                strLeaveHospital.setGmtCreate(new Date());//记录创建时间
                this.save(strLeaveHospital);
            }else{
                strLeaveHospital.setGmtModified(new Date());//记录修改时间
                this.update(strLeaveHospital,new QueryWrapper<StrLeaveHospital>()
                        .eq("rec_id", strLeaveHospital.getRecId())
                        .eq("hospital_id", strLeaveHospital.getHospitalId())
                        .eq("behospital_code", strLeaveHospital.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("出院小结",strLeaveHospital.getRecId(), JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrLeaveHospital strLeaveHospital){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrLeaveHospital>()
                .eq("rec_id", strLeaveHospital.getRecId())
                .eq("hospital_id", strLeaveHospital.getHospitalId())
                .eq("behospital_code", strLeaveHospital.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:出院小结-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrLeaveHospitalVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrLeaveHospitalVO strLeaveHospitalVO:list) {
                    if("".equals(strLeaveHospitalVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strLeaveHospitalVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strLeaveHospitalVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrLeaveHospital> strLeaveHospitalList= initData(list);
                execute(strLeaveHospitalList);

                if(logSwitch){
                    strLeaveHospitalList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-出院小结-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-出院小结-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrLeaveHospital> initData(List<StrLeaveHospitalVO> list) throws Exception{
        List<StrLeaveHospital> tList=Lists.newArrayList();
        for (StrLeaveHospitalVO s:list) {
            StrLeaveHospital t=new StrLeaveHospital();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getBehospitalDate())){
                t.setBehospitalDate(DateUtil.parseDateTime(s.getBehospitalDate()));//入院日期
            }
            if(StringUtil.isNotEmpty(s.getLeaveHospitalDate())){
                t.setLeaveHospitalDate(DateUtil.parseDateTime(s.getLeaveHospitalDate()));//出院日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.LEAVE_HOSPITAL.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrLeaveHospital> list){
        List<StrLeaveHospital> addE = Lists.newLinkedList();
        List<StrLeaveHospital> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrLeaveHospital strLeaveHospital = this.getOne(new QueryWrapper<StrLeaveHospital>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strLeaveHospital != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strLeaveHospitalService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
