package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrOperativeNote;
import com.diagbot.entity.StrOperativeNote;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrOperativeNoteServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrOperativeNoteVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrOperativeNoteVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrOperativeNoteFacade extends StrOperativeNoteServiceImpl {

    @Autowired
    @Qualifier("strOperativeNoteServiceImpl")
    private StrOperativeNoteServiceImpl strOperativeNoteService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strOperativeNote");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrOperativeNote strOperativeNote=new StrOperativeNote();
        strOperativeNote.setRecId(strContentVO.getRecId());
        strOperativeNote.setBehospitalCode(strContentVO.getBehospitalCode());
        strOperativeNote.setHospitalId(strContentVO.getHospitalId());
        strOperativeNote.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strOperativeNote)) {
            strOperativeNote.setGmtCreate(new Date());//记录创建时间
            this.save(strOperativeNote);
        } else {
            strOperativeNote.setGmtModified(new Date());//记录修改时间
            this.update(strOperativeNote, new QueryWrapper<StrOperativeNote>()
                    .eq("rec_id", strOperativeNote.getRecId())
                    .eq("hospital_id", strOperativeNote.getHospitalId())
                    .eq("behospital_code", strOperativeNote.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrOperativeNote strOperativeNote=new StrOperativeNote();
        try {
            AStrOperativeNoteVO strOperativeNoteVO=(AStrOperativeNoteVO) MapUtil.mapToObject(entityMap, AStrOperativeNoteVO.class);
            BeanUtils.copyProperties(strOperativeNoteVO,strOperativeNote);
            strOperativeNote.setHospitalId(hospitalId);//医院编码

            strOperativeNote.setAuditDate(DateUtil.parseDateTime(strOperativeNoteVO.getAuditDate()));//审核时间
            strOperativeNote.setRecDate(DateUtil.parseDateTime(strOperativeNoteVO.getRecDate()));//记录时间
            strOperativeNote.setOperationDate(DateUtil.parseDateTime(strOperativeNoteVO.getOperationDate()));//手术日期
            strOperativeNote.setStartTime(DateUtil.parseDate(strOperativeNoteVO.getStartTime()));//开始时间
            strOperativeNote.setEndTime(DateUtil.parseDate(strOperativeNoteVO.getEndTime()));//结束时间
            strOperativeNote.setRecordDate(DateUtil.parseDateTime(strOperativeNoteVO.getRecordDate()));//病历日期

            strOperativeNote.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strOperativeNote)){
                strOperativeNote.setGmtCreate(new Date());//记录创建时间
                this.save(strOperativeNote);
            }else{
                strOperativeNote.setGmtModified(new Date());//记录修改时间
                this.update(strOperativeNote,new QueryWrapper<StrOperativeNote>()
                        .eq("rec_id", strOperativeNote.getRecId())
                        .eq("hospital_id", strOperativeNote.getHospitalId())
                        .eq("behospital_code", strOperativeNote.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("手术记录", strOperativeNote.getRecId(),JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrOperativeNote strOperativeNote){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrOperativeNote>()
                .eq("rec_id", strOperativeNote.getRecId())
                .eq("hospital_id", strOperativeNote.getHospitalId())
                .eq("behospital_code", strOperativeNote.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:手术记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrOperativeNoteVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrOperativeNoteVO strOperativeNoteVO:list) {
                    if("".equals(strOperativeNoteVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strOperativeNoteVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strOperativeNoteVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrOperativeNote> strOperativeNoteList= initData(list);
                execute(strOperativeNoteList);

                if(logSwitch){
                    strOperativeNoteList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-手术记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-手术记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrOperativeNote> initData(List<StrOperativeNoteVO> list) throws Exception{
        List<StrOperativeNote> tList=Lists.newArrayList();
        for (StrOperativeNoteVO s:list) {
            StrOperativeNote t=new StrOperativeNote();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getOperationDate())){
                t.setOperationDate(DateUtil.parseDateTime(s.getOperationDate()));//手术日期
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            if(StringUtil.isNotEmpty(s.getStartTime())){
                t.setEndTime(DateUtil.parseDateTime(s.getStartTime()));//开始时间
            }
            if(StringUtil.isNotEmpty(s.getEndTime())){
                t.setEndTime(DateUtil.parseDateTime(s.getEndTime()));//结束时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.OPERATIVE_NOTE.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrOperativeNote> list){
        List<StrOperativeNote> addE = Lists.newLinkedList();
        List<StrOperativeNote> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrOperativeNote strOperativeNote = this.getOne(new QueryWrapper<StrOperativeNote>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strOperativeNote != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strOperativeNoteService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
