package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrPeriodConclusion;
import com.diagbot.entity.StrPeriodConclusion;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrPeriodConclusionServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrPeriodConclusionVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrPeriodConclusionVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrPeriodConclusionFacade extends StrPeriodConclusionServiceImpl {

    @Autowired
    @Qualifier("strPeriodConclusionServiceImpl")
    private StrPeriodConclusionServiceImpl strPeriodConclusionService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strPeriodConclusion");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrPeriodConclusion strPeriodConclusion=new StrPeriodConclusion();
        strPeriodConclusion.setRecId(strContentVO.getRecId());
        strPeriodConclusion.setBehospitalCode(strContentVO.getBehospitalCode());
        strPeriodConclusion.setHospitalId(strContentVO.getHospitalId());
        strPeriodConclusion.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strPeriodConclusion)) {
            strPeriodConclusion.setGmtCreate(new Date());//记录创建时间
            this.save(strPeriodConclusion);
        } else {
            strPeriodConclusion.setGmtModified(new Date());//记录修改时间
            this.update(strPeriodConclusion, new QueryWrapper<StrPeriodConclusion>()
                    .eq("rec_id", strPeriodConclusion.getRecId())
                    .eq("hospital_id", strPeriodConclusion.getHospitalId())
                    .eq("behospital_code", strPeriodConclusion.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrPeriodConclusion strPeriodConclusion=new StrPeriodConclusion();
        try {
            AStrPeriodConclusionVO strPeriodConclusionVO=(AStrPeriodConclusionVO) MapUtil.mapToObject(entityMap, AStrPeriodConclusionVO.class);
            BeanUtils.copyProperties(strPeriodConclusionVO,strPeriodConclusion);
            strPeriodConclusion.setHospitalId(hospitalId);//医院编码

            strPeriodConclusion.setAuditDate(DateUtil.parseDateTime(strPeriodConclusionVO.getAuditDate()));//审核时间
            strPeriodConclusion.setRecDate(DateUtil.parseDateTime(strPeriodConclusionVO.getRecDate()));//记录时间
            strPeriodConclusion.setRecordDate(DateUtil.parseDateTime(strPeriodConclusionVO.getRecordDate()));//病历日期

            strPeriodConclusion.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strPeriodConclusion)){
                strPeriodConclusion.setGmtCreate(new Date());//记录创建时间
                this.save(strPeriodConclusion);
            }else{
                strPeriodConclusion.setGmtModified(new Date());//记录修改时间
                this.update(strPeriodConclusion,new QueryWrapper<StrPeriodConclusion>()
                        .eq("rec_id", strPeriodConclusion.getRecId())
                        .eq("hospital_id", strPeriodConclusion.getHospitalId())
                        .eq("behospital_code", strPeriodConclusion.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("阶段小结",strPeriodConclusion.getRecId(),JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrPeriodConclusion strPeriodConclusion){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrPeriodConclusion>()
                .eq("rec_id", strPeriodConclusion.getRecId())
                .eq("hospital_id", strPeriodConclusion.getHospitalId())
                .eq("behospital_code", strPeriodConclusion.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:阶段小结-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrPeriodConclusionVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrPeriodConclusionVO strPeriodConclusionVO:list) {
                    if("".equals(strPeriodConclusionVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strPeriodConclusionVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strPeriodConclusionVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrPeriodConclusion> strPeriodConclusionList= initData(list);
                execute(strPeriodConclusionList);

                if(logSwitch){
                    strPeriodConclusionList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-阶段小结-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-阶段小结-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrPeriodConclusion> initData(List<StrPeriodConclusionVO> list) throws Exception{
        List<StrPeriodConclusion> tList=Lists.newArrayList();
        for (StrPeriodConclusionVO s:list) {
            StrPeriodConclusion t=new StrPeriodConclusion();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.PERIOD_CONCLUSION.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrPeriodConclusion> list){
        List<StrPeriodConclusion> addE = Lists.newLinkedList();
        List<StrPeriodConclusion> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrPeriodConclusion strPeriodConclusion = this.getOne(new QueryWrapper<StrPeriodConclusion>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strPeriodConclusion != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strPeriodConclusionService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }

}
