package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrRescueNote;
import com.diagbot.entity.StrRescueNote;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrRescueNoteServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrRescueNoteVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrRescueNoteVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrRescueNoteFacade extends StrRescueNoteServiceImpl {

    @Autowired
    @Qualifier("strRescueNoteServiceImpl")
    private StrRescueNoteServiceImpl strRescueNoteService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strRescueNote");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrRescueNote strRescueNote=new StrRescueNote();
        strRescueNote.setRecId(strContentVO.getRecId());
        strRescueNote.setBehospitalCode(strContentVO.getBehospitalCode());
        strRescueNote.setHospitalId(strContentVO.getHospitalId());
        strRescueNote.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strRescueNote)) {
            strRescueNote.setGmtCreate(new Date());//记录创建时间
            this.save(strRescueNote);
        } else {
            strRescueNote.setGmtModified(new Date());//记录修改时间
            this.update(strRescueNote, new QueryWrapper<StrRescueNote>()
                    .eq("rec_id", strRescueNote.getRecId())
                    .eq("hospital_id", strRescueNote.getHospitalId())
                    .eq("behospital_code", strRescueNote.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrRescueNote strRescueNote=new StrRescueNote();
        try {
            AStrRescueNoteVO strRescueNoteVO=(AStrRescueNoteVO) MapUtil.mapToObject(entityMap, AStrRescueNoteVO.class);
            BeanUtils.copyProperties(strRescueNoteVO,strRescueNote);
            strRescueNote.setHospitalId(hospitalId);//医院编码

            strRescueNote.setAuditDate(DateUtil.parseDateTime(strRescueNoteVO.getAuditDate()));//审核时间
            strRescueNote.setRecDate(DateUtil.parseDateTime(strRescueNoteVO.getRecDate()));//记录时间
            strRescueNote.setStartTime(DateUtil.parseDateTime(strRescueNoteVO.getStartTime()));//开始时间
            strRescueNote.setEndTime(DateUtil.parseDate(strRescueNoteVO.getEndTime()));//结束时间
            strRescueNote.setRecordDate(DateUtil.parseDateTime(strRescueNoteVO.getRecordDate()));//病历日期

            strRescueNote.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strRescueNote)){
                strRescueNote.setGmtCreate(new Date());//记录创建时间
                this.save(strRescueNote);
            }else{
                strRescueNote.setGmtModified(new Date());//记录修改时间
                this.update(strRescueNote,new QueryWrapper<StrRescueNote>()
                        .eq("rec_id", strRescueNote.getRecId())
                        .eq("hospital_id", strRescueNote.getHospitalId())
                        .eq("behospital_code", strRescueNote.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("抢救记录", strRescueNote.getRecId(),JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrRescueNote strRescueNote){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrRescueNote>()
                .eq("rec_id", strRescueNote.getRecId())
                .eq("hospital_id", strRescueNote.getHospitalId())
                .eq("behospital_code", strRescueNote.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:抢救记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrRescueNoteVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrRescueNoteVO strRescueNoteVO:list) {
                    if("".equals(strRescueNoteVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strRescueNoteVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strRescueNoteVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrRescueNote> strRescueNoteList= initData(list);
                execute(strRescueNoteList);

                if(logSwitch){
                    strRescueNoteList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-抢救记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-抢救记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrRescueNote> initData(List<StrRescueNoteVO> list) throws Exception{
        List<StrRescueNote> tList=Lists.newArrayList();
        for (StrRescueNoteVO s:list) {
            StrRescueNote t=new StrRescueNote();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            if(StringUtil.isNotEmpty(s.getStartTime())){
                t.setEndTime(DateUtil.parseDateTime(s.getStartTime()));//开始时间
            }
            if(StringUtil.isNotEmpty(s.getEndTime())){
                t.setEndTime(DateUtil.parseDateTime(s.getEndTime()));//结束时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.RESCUE_NOTE.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrRescueNote> list){
        List<StrRescueNote> addE = Lists.newLinkedList();
        List<StrRescueNote> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrRescueNote strRescueNote = this.getOne(new QueryWrapper<StrRescueNote>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strRescueNote != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strRescueNoteService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
