package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrTalkInform;
import com.diagbot.entity.StrTalkInform;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrTalkInformServiceImpl;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrTalkInformVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrTalkInformFacade extends StrTalkInformServiceImpl {
    @Autowired
    @Qualifier("strTalkInformServiceImpl")
    private StrTalkInformServiceImpl strTalkInformService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strTalkInform");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrTalkInform strTalkInform=new StrTalkInform();
        strTalkInform.setRecId(strContentVO.getRecId());
        strTalkInform.setBehospitalCode(strContentVO.getBehospitalCode());
        strTalkInform.setHospitalId(strContentVO.getHospitalId());
        //strTalkInform.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strTalkInform)) {
            strTalkInform.setGmtCreate(new Date());//记录创建时间
            this.save(strTalkInform);
        } else {
            strTalkInform.setGmtModified(new Date());//记录修改时间
            this.update(strTalkInform, new QueryWrapper<StrTalkInform>()
                    .eq("rec_id", strTalkInform.getRecId())
                    .eq("hospital_id", strTalkInform.getHospitalId())
                    .eq("behospital_code", strTalkInform.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrTalkInform strTalkInform=new StrTalkInform();
        try {
            StrTalkInformVO strTalkInformVO=(StrTalkInformVO) MapUtil.mapToObject(entityMap, StrTalkInformVO.class);
            BeanUtils.copyProperties(strTalkInformVO,strTalkInform);
            strTalkInform.setHospitalId(hospitalId);//医院编码

            //判断数据库中是否存在，不存在insert
            if(isExist(strTalkInform)){
                strTalkInform.setGmtCreate(new Date());//记录创建时间
                this.save(strTalkInform);
            }else{
                strTalkInform.setGmtModified(new Date());//记录修改时间
                this.update(strTalkInform,new QueryWrapper<StrTalkInform>()
                        .eq("rec_id", strTalkInform.getRecId())
                        .eq("hospital_id", strTalkInform.getHospitalId())
                        .eq("behospital_code", strTalkInform.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("病重通知单", strTalkInform.getRecId(),JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrTalkInform strTalkInform){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrTalkInform>()
                .eq("rec_id", strTalkInform.getRecId())
                .eq("hospital_id", strTalkInform.getHospitalId())
                .eq("behospital_code", strTalkInform.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:告知书记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrTalkInformVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrTalkInformVO strTalkInformVO:list) {
                    if("".equals(strTalkInformVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strTalkInformVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strTalkInformVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrTalkInform> strTalkInformList= initData(list);
                execute(strTalkInformList);

                if(logSwitch){
                    strTalkInformList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-告知书记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-告知书记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrTalkInform> initData(List<StrTalkInformVO> list) throws Exception{
        List<StrTalkInform> tList= Lists.newArrayList();
        for (StrTalkInformVO s:list) {
            StrTalkInform t=new StrTalkInform();
            BeanUtils.copyProperties(s,t);
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrTalkInform> list){
        List<StrTalkInform> addE = Lists.newLinkedList();
        List<StrTalkInform> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrTalkInform strTalkInform = this.getOne(new QueryWrapper<StrTalkInform>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strTalkInform != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strTalkInformService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
