package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrTransferOutNote;
import com.diagbot.entity.StrTransferOutNote;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrTransferOutNoteServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrTransferOutNoteVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrTransferOutNoteVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrTransferOutNoteFacade extends StrTransferOutNoteServiceImpl {

    @Autowired
    @Qualifier("strTransferOutNoteServiceImpl")
    private StrTransferOutNoteServiceImpl strTransferOutNoteService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strTransferOutNote");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrTransferOutNote strTransferOutNote=new StrTransferOutNote();
        strTransferOutNote.setRecId(strContentVO.getRecId());
        strTransferOutNote.setBehospitalCode(strContentVO.getBehospitalCode());
        strTransferOutNote.setHospitalId(strContentVO.getHospitalId());
        strTransferOutNote.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strTransferOutNote)) {
            strTransferOutNote.setGmtCreate(new Date());//记录创建时间
            this.save(strTransferOutNote);
        } else {
            strTransferOutNote.setGmtModified(new Date());//记录修改时间
            this.update(strTransferOutNote, new QueryWrapper<StrTransferOutNote>()
                    .eq("rec_id", strTransferOutNote.getRecId())
                    .eq("hospital_id", strTransferOutNote.getHospitalId())
                    .eq("behospital_code", strTransferOutNote.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrTransferOutNote strTransferOutNote=new StrTransferOutNote();
        try {
            AStrTransferOutNoteVO strTransferOutNoteVO=(AStrTransferOutNoteVO) MapUtil.mapToObject(entityMap, AStrTransferOutNoteVO.class);
            BeanUtils.copyProperties(strTransferOutNoteVO,strTransferOutNote);
            strTransferOutNote.setHospitalId(hospitalId);//医院编码
            strTransferOutNote.setTransferInDate(DateUtil.parseDateTime(strTransferOutNoteVO.getTransferInDate()));
            strTransferOutNote.setAuditDate(DateUtil.parseDateTime(strTransferOutNoteVO.getAuditDate()));//审核时间
            strTransferOutNote.setRecDate(DateUtil.parseDateTime(strTransferOutNoteVO.getRecDate()));//记录时间
            strTransferOutNote.setRecordDate(DateUtil.parseDateTime(strTransferOutNoteVO.getRecordDate()));//病历日期

            strTransferOutNote.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strTransferOutNote)){
                strTransferOutNote.setGmtCreate(new Date());//记录创建时间
                this.save(strTransferOutNote);
            }else{
                strTransferOutNote.setGmtModified(new Date());//记录修改时间
                this.update(strTransferOutNote,new QueryWrapper<StrTransferOutNote>()
                        .eq("rec_id", strTransferOutNote.getRecId())
                        .eq("hospital_id", strTransferOutNote.getHospitalId())
                        .eq("behospital_code", strTransferOutNote.getBehospitalCode()));
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("转出记录",strTransferOutNote.getRecId(), JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrTransferOutNote strTransferOutNote){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrTransferOutNote>()
                .eq("rec_id", strTransferOutNote.getRecId())
                .eq("hospital_id", strTransferOutNote.getHospitalId())
                .eq("behospital_code", strTransferOutNote.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:转出记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrTransferOutNoteVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrTransferOutNoteVO strTransferOutNoteVO:list) {
                    if("".equals(strTransferOutNoteVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strTransferOutNoteVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strTransferOutNoteVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrTransferOutNote> strTransferOutNoteList= initData(list);
                execute(strTransferOutNoteList);
                if(logSwitch){
                    strTransferOutNoteList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-转出记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-转出记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrTransferOutNote> initData(List<StrTransferOutNoteVO> list) throws Exception{
        List<StrTransferOutNote> tList=Lists.newArrayList();
        for (StrTransferOutNoteVO s:list) {
            StrTransferOutNote t=new StrTransferOutNote();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getTransferInDate())){
                t.setTransferInDate(DateUtil.parseDateTime(s.getTransferInDate()));//转入日期
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.TRANSFER_OUT_NOTE.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            //t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrTransferOutNote> list){
        List<StrTransferOutNote> addE = Lists.newLinkedList();
        List<StrTransferOutNote> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrTransferOutNote strTransferOutNote = this.getOne(new QueryWrapper<StrTransferOutNote>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strTransferOutNote != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strTransferOutNoteService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
