package com.diagbot.facade.str;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.ColumnZhAndChDTO;
import com.diagbot.entity.StrWardRecord;
import com.diagbot.entity.StrWardRecord;
import com.diagbot.enums.CacheKeyEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.data.AMedAbnormalInfoFacade;
import com.diagbot.facade.data.ColumnFacade;
import com.diagbot.service.impl.StrWardRecordServiceImpl;
import com.diagbot.util.DateUtil;
import com.diagbot.util.EntityUtil;
import com.diagbot.util.MapUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.vo.data.AStrWardRecordVO;
import com.diagbot.vo.str.StrContentVO;
import com.diagbot.vo.str.StrWardRecordVO;
import com.google.common.collect.Lists;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class BStrWardRecordFacade extends StrWardRecordServiceImpl {

    @Autowired
    @Qualifier("strWardRecordServiceImpl")
    private StrWardRecordServiceImpl strWardRecordService;
    @Autowired
    private ColumnFacade columnFacade;
    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;
    @Value("${log_switch.enable}")
    private boolean logSwitch;

    public void getColumnZhAndCh(){
        List<ColumnZhAndChDTO> list=this.baseMapper.getColumnZhAndCh();
        list.forEach(s->{
            s.setEn(NamingStrategy.underlineToCamel(s.getEn()));
        });

        Map<String, String> columnMap= EntityUtil.makeMapWithKeyValue(list,"ch","en");
        Boolean flag=columnFacade.createColumn(columnMap,"strWardRecord");

        //Map<String, String> map=columnFacade.getColumn("strConsultationNote");
        if(!flag){
            return;
        }
    }

    /**
     * @Description:不解析时入库
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(StrContentVO strContentVO){
        StrWardRecord strWardRecord=new StrWardRecord();
        strWardRecord.setRecId(strContentVO.getRecId());
        strWardRecord.setBehospitalCode(strContentVO.getBehospitalCode());
        strWardRecord.setHospitalId(strContentVO.getHospitalId());
        strWardRecord.setWholeData(strContentVO.getWholeData());
        //判断数据库中是否存在，不存在insert
        if (isExist(strWardRecord)) {
            strWardRecord.setGmtCreate(new Date());//记录创建时间
            this.save(strWardRecord);
        } else {
            strWardRecord.setGmtModified(new Date());//记录修改时间
            this.update(strWardRecord, new QueryWrapper<StrWardRecord>()
                    .eq("rec_id", strWardRecord.getRecId())
                    .eq("hospital_id", strWardRecord.getHospitalId())
                    .eq("behospital_code", strWardRecord.getBehospitalCode()));
        }
    }

    /**
     * @Description:解析后存储数据
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public void dealData(String columnMap,Map<String, Object> entityMap,Long hospitalId){
        StrWardRecord strWardRecord=new StrWardRecord();
        try {
            AStrWardRecordVO strWardRecordVO=(AStrWardRecordVO) MapUtil.mapToObject(entityMap, AStrWardRecordVO.class);
            BeanUtils.copyProperties(strWardRecordVO,strWardRecord);
            strWardRecord.setHospitalId(hospitalId);//医院编码

            strWardRecord.setAuditDate(DateUtil.parseDateTime(strWardRecordVO.getAuditDate()));//审核时间
            strWardRecord.setRecDate(DateUtil.parseDateTime(strWardRecordVO.getRecDate()));//记录时间
            strWardRecord.setWardDate(DateUtil.parseDateTime(strWardRecordVO.getWardDate()));//查房日期
            strWardRecord.setRecordDate(DateUtil.parseDateTime(strWardRecordVO.getRecordDate()));//病历日期

            strWardRecord.setWholeData(columnMap);
            //判断数据库中是否存在，不存在insert
            if(isExist(strWardRecord)){
                strWardRecord.setGmtCreate(new Date());//记录创建时间
                this.save(strWardRecord);
            }else{
                strWardRecord.setGmtModified(new Date());//记录修改时间
                this.update(strWardRecord,new QueryWrapper<StrWardRecord>()
                        .eq("rec_id", strWardRecord.getRecId())
                        .eq("hospital_id", strWardRecord.getHospitalId())
                        .eq("behospital_code", strWardRecord.getBehospitalCode()));
            }

        }catch (Exception e){
            log.error(e.getMessage(),e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("查房记录", strWardRecord.getRecId(),JSON.toJSONString(entityMap),"",e.getMessage());
        }

    }

    public Boolean isExist(StrWardRecord strWardRecord){
        Boolean flag=true;
        int count = this.baseMapper.selectCount(new QueryWrapper<StrWardRecord>()
                .eq("rec_id", strWardRecord.getRecId())
                .eq("hospital_id", strWardRecord.getHospitalId())
                .eq("behospital_code", strWardRecord.getBehospitalCode()));
        if(count>0){
            flag=false;
        }
        return flag;
    }

    /**
     * @Description:查房记录-结构化-独立入口
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO execDealData(List<StrWardRecordVO> list){
        try{
            if(list!=null && list.size()>0){
                //循环验证数据有效性
                for (StrWardRecordVO strWardRecordVO:list) {
                    if("".equals(strWardRecordVO.getRecId())) {
                        return RespDTO.onError("请输入记录编号!");
                    }else if(strWardRecordVO.getHospitalId()==null){
                        return RespDTO.onError("请输入医院编码!");
                    }else if("".equals(strWardRecordVO.getBehospitalCode())){
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //初始、格式化数据
                List<StrWardRecord> strWardRecordList= initData(list);
                execute(strWardRecordList);

                if(logSwitch){
                    strWardRecordList.forEach(s->{
                        aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-查房记录-正常", s.getRecId(), JSON.toJSONString(s), "", "");
                    });
                }
                return RespDTO.onSuc("操作正常！");
            }else{
                return RespDTO.onError("未接收到数据!");
            }
        }catch (Exception e){
            log.error(e.getMessage(),e);
            if(list!=null && list.size()>0) {
                list.forEach(s->{
                    aMedAbnormalInfoFacade.saveAbnormalInfo("结构化-查房记录-异常", s.getRecId(), JSON.toJSONString(list), "", e.getMessage());
                });
            }
            return RespDTO.onError("数据处理异常，详情查看日志表");
        }
    }

    private List<StrWardRecord> initData(List<StrWardRecordVO> list) throws Exception{
        List<StrWardRecord> tList=Lists.newArrayList();
        for (StrWardRecordVO s:list) {
            StrWardRecord t=new StrWardRecord();
            BeanUtils.copyProperties(s,t);
            if(StringUtil.isNotEmpty(s.getRecordDate())){
                t.setRecordDate(DateUtil.parseDateTime(s.getRecordDate()));//病历日期
            }
            if(StringUtil.isNotEmpty(s.getRecDate())){
                t.setRecDate(DateUtil.parseDateTime(s.getRecDate()));//记录时间
            }
            if(StringUtil.isNotEmpty(s.getWardDate())){
                t.setWardDate(DateUtil.parseDateTime(s.getWardDate()));//查房日期
            }
            if(StringUtil.isNotEmpty(s.getAuditDate())){
                t.setAuditDate(DateUtil.parseDateTime(s.getAuditDate()));//审核时间
            }
            Map<String, String> columnMap=columnFacade.getColumn(CacheKeyEnum.WARD_RECORD.getName());
            Map<String, Object> entityMap=MapUtil.objectToMap(s);
            Map<String, Object> wholeMap=MapUtil.objcetKeyConvert(columnMap,entityMap);
            t.setWholeData(JSON.toJSONString(wholeMap));
            tList.add(t);
        }
        return tList;
    }

    public void execute(List<StrWardRecord> list){
        List<StrWardRecord> addE = Lists.newLinkedList();
        List<StrWardRecord> updateE = Lists.newLinkedList();
        if (list != null && list.size() > 0) {
            list.stream().forEach(s -> {
                StrWardRecord strWardRecord = this.getOne(new QueryWrapper<StrWardRecord>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("rec_id", s.getRecId())
                        .eq("hospital_id", s.getHospitalId())
                        .eq("behospital_code",s.getBehospitalCode()), false);
                if (strWardRecord != null) {
                    s.setGmtModified(new Date());
                    updateE.add(s);
                } else {
                    s.setGmtCreate(new Date());
                    addE.add(s);
                }
            });
        }
        if(addE.size()>0){
            strWardRecordService.saveBatch(addE);
        }
        if(updateE.size()>0){
            this.baseMapper.updateBatchByKey(updateE);
        }
    }
}
